@@ -78,10 +78,17 @@
 #endif
 #endif
 
-#if defined(__NetBSD__) || defined(__OpenBSD__)
+#if defined(__OpenBSD__)
 #define HAVE_GETADDRINFO	1
 #endif
 
+#if defined(__NetBSD__)
+#define HAVE_GETADDRINFO	1
+#  if __NetBSD_Version__ <= 105010000
+#    define sa_family_t unsigned char
+#  endif
+#endif
+
 #if defined(__solaris__)
 # include <netconfig.h>
 # if defined(NC_INET6)
@@ -137,7 +144,7 @@ extern int	errno;
 */
 #define GKRELLMD_VERSION_MAJOR   2
 #define GKRELLMD_VERSION_MINOR   1
-#define GKRELLMD_VERSION_REV     16
+#define GKRELLMD_VERSION_REV     21
 #define GKRELLMD_EXTRAVERSION    ""
 
 #define GKRELLMD_CONFIG     "gkrellmd.conf"
@@ -232,3 +239,29 @@ gint			gkrellmd_send_to_client(GkrellmdClient *client, gchar *buf);
 void			gkrellmd_free_glist_and_data(GList **);
 void			gkrellmd_add_mailbox(gchar *);
 void			gkrellmd_add_serveflag_done(gboolean *);
+
+
+
+#if !GLIB_CHECK_VERSION(2,0,0)
+/* glib2 compatibility functions
+*/
+#define G_FILE_TEST_EXISTS		1
+#define G_FILE_TEST_IS_DIR		2
+#define	G_FILE_TEST_IS_REGULAR	3
+
+#include <dirent.h>
+
+typedef struct
+    {
+    DIR     *dir;
+	}
+    GDir;
+
+GDir		*g_dir_open(gchar *path, guint flags, gpointer error);
+gchar		*g_dir_read_name(GDir *dir);
+void		g_dir_close(GDir *dir);
+gboolean	g_file_test(gchar *filename, gint test);
+gchar		*g_build_filename(gchar *first, ...);
+
+#endif
+
