@@ -212,75 +212,6 @@ sylpheed_mark_new_count(Mailbox *mbox)
 	return TRUE;
 	}
 
-#if !GLIB_CHECK_VERSION(2,0,0)
-/* glib2 compatibility functions
-*/
-#include <dirent.h>
-
-
-typedef struct
-	{
-	DIR		*dir;
-	}
-	GDir;
-
-static GDir *
-g_dir_open(gchar *path, guint flags, gpointer error)
-	{
-	GDir	*gdir;
-	DIR		*dir;
-
-	dir = opendir(path);
-	if (!dir)
-		return NULL;
-	gdir = g_new0(GDir, 1);
-	gdir->dir = dir;
-	return gdir;
-	}
-
-static gchar*
-g_dir_read_name(GDir *dir)
-	{
-	struct dirent *entry;
-
-	while ((entry = readdir(dir->dir)) != NULL)
-		{
-		if (   !strcmp(entry->d_name, ".")
-			|| !strcmp(entry->d_name, "..")
-		   )
-			continue;
-		return entry->d_name;
-		}
-	return NULL;
-	}
-
-static void
-g_dir_close(GDir *dir)
-	{
-	closedir(dir->dir);
-	g_free(dir);
-	}
-
-
-#define G_FILE_TEST_EXISTS	1
-#define	G_FILE_TEST_IS_DIR	2
-
-static gboolean
-g_file_test(gchar *filename, gint test)
-	{
-	struct stat		s;
-
-	if ((test & G_FILE_TEST_EXISTS) && (access(filename, F_OK) == 0))
-		return TRUE;
-	if (   (test & G_FILE_TEST_IS_DIR)
-		&& stat(filename, &s) == 0
-		&& S_ISDIR (s.st_mode)
-	   )
-		return TRUE;
-	return FALSE;
-	}
-#endif
-
 
   /* Check a mh directory for mail. The way that messages are marked as new
   |  depends on the MUA being using.  Only .mh_sequences and .sylpheed_mark
