@@ -65,8 +65,13 @@ make_pidfile(void)
 	if (!_GK.pidfile)
 		return;
 	f = fopen(_GK.pidfile, "w");
-	fprintf(f, "%d\n", getpid());
-	fclose(f);
+	if (f)
+		{
+		fprintf(f, "%d\n", getpid());
+		fclose(f);
+		}
+	else
+		fprintf(stderr, "gkrellmd: Can't create pidfile %s\n", _GK.pidfile);
 #endif
 	}
 
@@ -87,9 +92,24 @@ cb_sigterm(gint sig)
 	}
 
 gint
-send_to_client(gint fd, gchar *buf)
+gkrellmd_send_to_client(GkrellmdClient *client, gchar *buf)
 	{
-	return send(fd, buf, strlen(buf), 0);
+	gint	n;
+
+	if (!client->alive)
+		return 0;
+#if defined(MSG_NOSIGNAL)
+	n = send(client->fd, buf, strlen(buf), MSG_NOSIGNAL);
+#else
+	n = send(client->fd, buf, strlen(buf), 0);
+#endif
+	if (n < 0 && errno == EPIPE)
+		{
+		if (_GK.verbose)
+			printf("Write on closed pipe to host %s\n", client->hostname);
+		client->alive = FALSE;
+		}
+	return n;
 	}
 
 #if 0
@@ -179,6 +199,7 @@ allow_host(GkrellmdClient *client, struct sockaddr *sa, socklen_t salen)
 	gchar			buf[128];
 	gchar			*hostname = NULL,
 					*addr = NULL;
+	gchar			*s, *allowed;
 
 #ifdef HAVE_GETADDRINFO
 	error = getnameinfo(sa, salen, addrbuf, sizeof(addrbuf),
@@ -206,17 +227,30 @@ allow_host(GkrellmdClient *client, struct sockaddr *sa, socklen_t salen)
 		return TRUE;
 
 	for (list = allow_host_list; list; list = list->next)
-		if (   (hostname && !strcmp(hostname, (gchar *) list->data))
-			|| (addr && !strcmp(addr, (gchar *) list->data))
-			|| !strcmp("ALL", (gchar *) list->data)
+		{
+		allowed = (gchar *) list->data;
+		if (   (hostname && !strcmp(hostname, allowed))
+			|| (addr && !strcmp(addr, allowed))
+			|| !strcmp("ALL", allowed)
 		   )
 			return TRUE;
 
+		/* Check for simple IPv4 subnet match.  Worry later about ranges and
+		|  other hosts_access type patterns.
+		*/
+		if (   addr
+			&& (s = strrchr(allowed, (int) '.')) != NULL
+			&& *(s + 1) == '*' && *(s + 2) == '\0'
+			&& !strncmp(addr, allowed, (gint) (s - allowed + 1))
+		   )
+				return TRUE;
+		}
+
 	snprintf(buf, sizeof(buf), _("Connection not allowed from %s\n"),
 			hostname ? hostname : addr);
 	fprintf(stderr, "gkrellmd: %s", buf),
-	send_to_client(client->fd, "<error>\n");
-	send_to_client(client->fd, buf);
+	gkrellmd_send_to_client(client, "<error>\n");
+	gkrellmd_send_to_client(client, buf);
 	return FALSE;
 	}
 
@@ -232,6 +266,7 @@ accept_client(gint fd, struct sockaddr *sa, socklen_t salen)
 
 	client = g_new0(GkrellmdClient, 1);
 	client->fd = fd;
+	client->alive = TRUE;
 	client_limit = (g_list_length(gkrellmd_client_list) >= _GK.max_clients);
 
 	if (!allow_host(client, sa, salen) || client_limit)
@@ -240,7 +275,8 @@ accept_client(gint fd, struct sockaddr *sa, socklen_t salen)
 			{
 			fprintf(stderr, _("gkrellmd: too many clients, rejecting %s\n"),
 					client->hostname);
-			send_to_client(fd, "<error>\nClient limit exceeded.\n");
+			gkrellmd_send_to_client(client,
+						"<error>\nClient limit exceeded.\n");
 			}
 		g_free(client->hostname);
 		g_free(client);
@@ -256,7 +292,7 @@ accept_client(gint fd, struct sockaddr *sa, socklen_t salen)
 	if (_GK.verbose)
 		printf(_("connect string from client: %s\n"), buf);
 
-	if (   sscanf(buf, "%32s %d.%d.%d", name, &client->major_version,
+	if (   sscanf(buf, "%31s %d.%d.%d", name, &client->major_version,
 					&client->minor_version, &client->rev_version) == 4
 		&& !strcmp(name, "gkrellm")
 	   )
@@ -266,7 +302,7 @@ accept_client(gint fd, struct sockaddr *sa, socklen_t salen)
 		}
 	fprintf(stderr, _("gkrellmd: bad connect line from %s: %s\n"),
 				client->hostname, buf);
-	send_to_client(fd, "<error>\nBad connect string!");
+	gkrellmd_send_to_client(client, "<error>\nBad connect string!");
 
 	g_free(client->hostname);
 	g_free(client);
@@ -284,6 +320,8 @@ remove_client(gint fd)
 		client = (GkrellmdClient *) list->data;
 		if (client->fd == fd)
 			{
+			if (_GK.verbose)
+				printf("Removing client %s\n", client->hostname);
 			close(fd);
 			g_free(client->hostname);
 			g_free(client);
@@ -298,7 +336,7 @@ parse_config(gchar *config, gchar *arg)
 	{
 	if (!strcmp(config, "clear-hosts") || !strcmp(config, "c"))
 		{
-		free_glist_and_data(&allow_host_list);
+		gkrellmd_free_glist_and_data(&allow_host_list);
 		return 0;
 		}
 	if (!strcmp(config, "detach") || !strcmp(config, "d"))
@@ -329,6 +367,8 @@ parse_config(gchar *config, gchar *arg)
 #if !defined(WIN32)
 	else if (!strcmp(config, "pidfile"))
 		_GK.pidfile = g_strdup(arg);
+	else if (!strcmp(config, "mailbox"))
+		gkrellmd_add_mailbox(arg);
 	else if (!strcmp(config, "user") || !strcmp(config, "U"))
 		{
 		struct passwd *tmp;
@@ -367,7 +407,7 @@ load_config(gchar *path)
 		if (!buf[0] || buf[0] == '#')
 			continue;
 		arg[0] = '\0';
-		sscanf(buf, "%32s %128s", config, arg);
+		sscanf(buf, "%31s %127s", config, arg);
 		parse_config(config, arg);
 		}
 	fclose(f);
@@ -424,6 +464,7 @@ usage(void)
 	printf(_("       --reconnect-timeout N Try to connect every N seconds after\n"
 	         "                             a disconnect\n"));
 #if !defined(WIN32)
+	printf(_("       --mailbox path        Send local mailbox counts to gkrellm clients.\n"));
 	printf(_("   -d, --detach              Run in background and detach from terminal\n"));
 	printf(_("   -U, --user username       Change to this username after startup\n"));
 	printf(_("   -G, --group groupname     Change to this group after startup\n"));
@@ -460,7 +501,7 @@ get_args(gint argc, gchar **argv)
 			}
 		else if (!strcmp(opt, "version") || !strcmp(opt, "v"))
 			{
-			printf("gkrellmd %d.%d.%d %s\n", GKRELLMD_VERSION_MAJOR,
+			printf("gkrellmd %d.%d.%d%s\n", GKRELLMD_VERSION_MAJOR,
 					GKRELLMD_VERSION_MINOR, GKRELLMD_VERSION_REV,
 					GKRELLMD_EXTRAVERSION);
 			exit(0);
@@ -492,9 +533,9 @@ socksetup(int af)
 #endif
 
 	memset(&hints, 0, sizeof(hints));
-	hints.ai_flags = AI_PASSIVE;
 	hints.ai_socktype = SOCK_STREAM;
 #ifdef HAVE_GETADDRINFO
+	hints.ai_flags = AI_PASSIVE;
 	hints.ai_family = af;
 	snprintf(portnumber, sizeof(portnumber), "%d", _GK.server_port);
 	error = getaddrinfo(NULL, portnumber, &hints, &res);
@@ -535,16 +576,29 @@ socksetup(int af)
 		*s = socket(r->ai_family, r->ai_socktype, r->ai_protocol);
 		if (*s < 0)
 			continue;
+
+		/* SO_REUSEADDR flag allows the server to restart immediately
+		*/
+		if (1)
+			{
+			const int on = 1;
+
+			if (setsockopt(*s, SOL_SOCKET, SO_REUSEADDR, &on, sizeof(on)) < 0)
+				{
+				fprintf(stderr, "gkrellmd setsockopt (SO_REUSEADDR) failed\n");
+				close(*s);
+				continue;
+				}
+			}
+
 #ifdef IPV6_V6ONLY
 		if (r->ai_family == AF_INET6)
 			{
 			const int on = 1;
 
-			if (setsockopt(*s, IPPROTO_IPV6, IPV6_V6ONLY,
-				       &on, sizeof(on)) < 0)
+			if (setsockopt(*s, IPPROTO_IPV6, IPV6_V6ONLY, &on, sizeof(on)) < 0)
 				{
-				fprintf(stderr,
-					"gkrellmd setsockopt (IPV6_V6ONLY) failed\n");
+				fprintf(stderr, "gkrellmd setsockopt (IPV6_V6ONLY) failed\n");
 				close(*s);
 				continue;
 				}
@@ -632,6 +686,9 @@ detach_from_terminal(void)
 	signal(SIGTTOU, SIG_IGN);
 	signal(SIGTTIN, SIG_IGN);
 	signal(SIGHUP, SIG_IGN);
+#if !defined(MSG_NOSIGNAL)
+	signal(SIGPIPE, SIG_IGN);
+#endif
 #endif
 	}
 
@@ -678,6 +735,7 @@ main(gint argc, gchar **argv)
 	size_t				addr_len;
 	gint				fd, server_fd, client_fd, nbytes, i;
 	gint				max_fd = -1;
+	gint				listen_fds = 0;
 	gint				interval, result;
 
 #if defined(WIN32) && defined(_WINDOWS)
@@ -722,12 +780,12 @@ main(gint argc, gchar **argv)
 		_GK.update_HZ = 3;
 	if (_GK.fs_interval < 1 || _GK.fs_interval > 1000)
 		_GK.fs_interval = 2;
-	if (_GK.nfs_interval < 1 || _GK.nfs_interval > 10000)
+	if (_GK.nfs_interval > 10000)
 		_GK.nfs_interval = 16;
 	if (_GK.inet_interval > 20)
 		_GK.inet_interval = 20;
 
-	load_monitors();
+	gkrellmd_load_monitors();
 
 	_GK.server_fd = socksetup(PF_UNSPEC);
 	if (_GK.server_fd == NULL)
@@ -744,14 +802,20 @@ main(gint argc, gchar **argv)
 		{
 		if (listen(_GK.server_fd[i], 5) == -1)
 			{
-			fprintf(stderr, "gkrellmd listen() failed: %s\n", strerror(errno));
-			remove_pidfile();
-			exit(1);
+			close(_GK.server_fd[i]);
+			continue;
 			}
+		++listen_fds;
 		FD_SET(_GK.server_fd[i], &read_fds);
 		if (max_fd < _GK.server_fd[i])
 			max_fd = _GK.server_fd[i];
 		}
+	if (listen_fds <= 0)
+		{
+		fprintf(stderr, "gkrellmd listen() failed: %s\n", strerror(errno));
+		remove_pidfile();
+		exit(1);
+		}
 
 	interval = 1000000 / _GK.update_HZ;
 
@@ -788,7 +852,7 @@ main(gint argc, gchar **argv)
 #if 0	/* BUG, result is 0 when test_fds has a set fd!! */
 		if (result == 0)	
 			{
-			update_monitors();
+			gkrellmd_update_monitors();
 			continue;
 			}
 #endif
@@ -840,10 +904,10 @@ main(gint argc, gchar **argv)
 					FD_CLR(fd, &read_fds);
 					}
 				else
-					gkrellm_client_read(fd, nbytes);
+					gkrellmd_client_read(fd, nbytes);
 				}
 			}
-		update_monitors();
+		gkrellmd_update_monitors();
 		}
 	return 0;
 	}
