@@ -48,8 +48,7 @@ typedef struct
 
 	GkrellmAlert		*alert;
 
-	gboolean			enabled,
-						real;
+	gboolean			enabled;
 
 	BatteryDisplayMode	display_mode;
 	gfloat				charge_rate;	/* % / min */
@@ -66,7 +65,11 @@ static GList			*battery_list;
 static GkrellmMonitor	*mon_battery;
 static GtkWidget		*battery_vbox;
 
-static gboolean			enable_battery, 
+static Battery			*composite_battery,
+						*launch_battery;
+
+static gboolean			enable_composite,
+						enable_each,
 						enable_estimate;
 
 static gint				poll_interval = 5,
@@ -74,29 +77,50 @@ static gint				poll_interval = 5,
 
 static GkrellmLauncher	launch;
 
+static GkrellmAlert		*bat_alert;		/* One alert dupped for each battery */
+
 static gint				style_id;
 
 static gboolean			alert_units_are_percent,
 						alert_units_need_estimate_mode;
 
-
 static void		(*read_battery_data)();
 static void		create_battery_panel(Battery *bat, gboolean first_create);
 
+static gint		n_batteries;
+
 
 static Battery *
-battery_nth(gint n)
+battery_nth(gint n, gboolean create)
 	{
-	Battery		*bat;
-	static gint	n_batteries;
+	Battery			*bat;
 
-	if (n < 0 || n > 10)
+	if (n > 10)
 		return NULL;
-	while ((bat = (Battery *)g_list_nth_data(battery_list, n)) == NULL)
+	if (n < 0)
+		{
+		if (!composite_battery && create)
+			{
+			bat = g_new0(Battery, 1);
+			battery_list = g_list_prepend(battery_list, bat);
+			bat->id = GKRELLM_BATTERY_COMPOSITE_ID;		/* -1 */
+			composite_battery = bat;
+			gkrellm_alert_dup(&bat->alert, bat_alert);
+			}
+		return composite_battery;
+		}
+
+	if (composite_battery)
+		++n;
+
+	while (   (bat = (Battery *) g_list_nth_data(battery_list, n)) == NULL
+		   && create
+		  )
 		{
 		bat = g_new0(Battery, 1);
 		battery_list = g_list_append(battery_list, bat);
 		bat->id = n_batteries++;
+		gkrellm_alert_dup(&bat->alert, bat_alert);
 		}
 	return bat;
 	}
@@ -107,12 +131,10 @@ battery_nth(gint n)
 static void
 read_battery_demo(void)
 	{
-	gboolean	present, on_line, charging;
+	gboolean	on_line, charging;
 	gint		percent, time_left;
 	static gint	bump = 60;
 
-	present = TRUE;
-
 	if (bump <= 5)
 		bump = 60;
 	bump -= 5;
@@ -129,7 +151,7 @@ read_battery_demo(void)
 		time_left = bump;
 		percent = 1 + bump;
 		}
-	gkrellm_battery_assign_data(0, present, on_line, charging,
+	gkrellm_battery_assign_data(0, TRUE, on_line, charging,
 				percent, time_left);
 	}
 
@@ -138,9 +160,7 @@ static gboolean
 setup_battery_interface(void)
 	{
     if (!read_battery_data && !_GK.client_mode && gkrellm_sys_battery_init())
-        {
         read_battery_data = gkrellm_sys_battery_read_data;
-        }
 	if (_GK.demo)
 		read_battery_data = read_battery_demo;
     return read_battery_data ? TRUE : FALSE;
@@ -158,7 +178,7 @@ gkrellm_battery_assign_data(gint n, gboolean present, gboolean on_line,
 	{
 	Battery	*bat;
 
-	bat = battery_nth(n);
+	bat = battery_nth(n, TRUE);
 	if (!bat)
 		return;
 	bat->present = present;
@@ -166,7 +186,6 @@ gkrellm_battery_assign_data(gint n, gboolean present, gboolean on_line,
 	bat->charging = charging;
 	bat->percent = percent;
 	bat->time_left = time_left;
-	bat->real = TRUE;
 	}
 
   /* Help out some laptops with Linux ACPI bugs */
@@ -179,6 +198,7 @@ gkrellm_battery_full_cap_fallback(void)
 
 /* -------------------------------------------------------------- */
 
+
 /* estimate (guess-timate?) battery time remaining, based on the rate of 
    discharge (and conversely the time to charge based on the rate of charge).
   - some BIOS' only provide battery levels, not any estimate of the time
@@ -380,6 +400,8 @@ draw_time_left_decal(Battery *bat, gboolean force)
 	int				battery_display_mode = bat->display_mode;
 	static BatteryDisplayMode	last_mode = BATTERYDISPLAY_EOM;
 
+	if (!bat->panel)
+		return;
 	if (bat->time_left == -1)
 		battery_display_mode = BATTERYDISPLAY_PERCENT;
 	if (last_mode != battery_display_mode)
@@ -424,6 +446,8 @@ update_battery_panel(Battery *bat)
 	{
 	GkrellmPanel	*p  = bat->panel;
 
+	if (!p)
+		return;
 	if (!bat->present)
 		{	/* Battery can be removed while running */
 		gkrellm_panel_hide(p);
@@ -447,9 +471,14 @@ update_battery_panel(Battery *bat)
 		}
 	else
 		{
-		gkrellm_thaw_alert(bat->alert);
-		gkrellm_check_alert(bat->alert, alert_units_are_percent
-					? bat->percent : bat->time_left);
+		if (   (bat == composite_battery && enable_composite)
+			|| (bat != composite_battery && enable_each)
+			)
+			{
+			gkrellm_thaw_alert(bat->alert);
+			gkrellm_check_alert(bat->alert, alert_units_are_percent
+						? bat->percent : bat->time_left);
+			}
 		gkrellm_draw_decal_pixmap(p, bat->power_decal, D_MISC_BATTERY);
 		}
 	draw_time_left_decal(bat, FALSE);
@@ -465,9 +494,11 @@ update_battery(void)
 	Battery		*bat;
 	static gint	seconds = 0;
 
+	if (!enable_each && !enable_composite)
+		return;
 	if (GK.second_tick)
 		{
-		if (enable_battery && (seconds == 0))
+		if (seconds == 0)
 			{
 			for (list = battery_list; list; list = list->next)
 				((Battery *) list->data)->present = FALSE;
@@ -478,6 +509,7 @@ update_battery(void)
 				bat = (Battery *) list->data;
 				if (!bat->panel)
 					create_battery_panel(bat, TRUE);
+				if (bat->enabled)
 				update_battery_panel(bat);
 				}
 			}
@@ -598,10 +630,20 @@ create_battery_panel(Battery *bat, gboolean first_create)
 		g_signal_connect(G_OBJECT(p->drawing_area), "leave_notify_event",
                 G_CALLBACK(cb_panel_leave), bat);
 		 }
-	if (bat->id == 0)
+	if (   (bat == composite_battery && enable_composite)
+		|| (bat->id == 0 && composite_battery && !enable_composite)
+		|| (bat->id == 0 && !composite_battery)
+		)
+		{
 		gkrellm_setup_decal_launcher(p, &launch, bat->time_decal);
+		launch_battery = bat;
+		}
+
+	if (bat == composite_battery)
+		bat->enabled = enable_composite;
+	else
+		bat->enabled = enable_each;
 
-	bat->enabled = enable_battery;
 	if (bat->enabled)
 		update_battery_panel(bat);
 	else
@@ -634,7 +676,7 @@ create_battery(GtkWidget *vbox, gint first_create)
 
 	battery_vbox = vbox;
 	if (_GK.demo)
-		enable_battery = TRUE;
+		enable_each = TRUE;
 	for (list = battery_list; list; list = list->next)
 		{
 		bat = (Battery *) list->data;
@@ -670,7 +712,7 @@ cb_command_process(GkrellmAlert *alert, gchar *src, gchar *buf, gint size,
 			value = -1;
 			if ((c = *(s + 1)) == 'H')
 				len = snprintf(buf, size, "%s", gkrellm_sys_get_host_name());
-			else if (c == 'n')
+			else if (c == 'n' && bat != composite_battery)
 				value = bat->id;
 			else if (c == 't')
 				value = bat->time_left;
@@ -680,6 +722,9 @@ cb_command_process(GkrellmAlert *alert, gchar *src, gchar *buf, gint size,
 				value = bat->on_line;
 			else if (c == 'c')
 				value = bat->charging;
+			else
+				len = 0;
+
 			if (value >= 0)
 				len = snprintf(buf, size, "%d", value);
 			++s;
@@ -708,6 +753,24 @@ cb_battery_alert_trigger(GkrellmAlert *alert, Battery *bat)
 	gkrellm_render_default_alert_decal(alert);
 	}
 
+static void
+dup_battery_alert(void)
+	{
+	GList	*list;
+	Battery	*bat;
+
+	for (list = battery_list; list; list = list->next)
+		{
+		bat = (Battery *) list->data;
+		gkrellm_alert_dup(&bat->alert, bat_alert);
+		gkrellm_alert_trigger_connect(bat->alert,
+					cb_battery_alert_trigger, bat);
+		gkrellm_alert_command_process_connect(bat->alert,
+					cb_command_process, bat);
+		}
+	}
+
+
   /* If the OS reports battery times, alerts will always have minutes units.
   |  If the OS does not report battery times the initial alert create will
   |  have minutes units if the estimate time option is enabled and it will
@@ -715,37 +778,39 @@ cb_battery_alert_trigger(GkrellmAlert *alert, Battery *bat)
   |  creates from load config will have units in effect at last save config.
   */
 static void
-create_battery_alert(Battery *bat, gboolean using_percent)
+create_alert(gboolean using_percent)
 	{
-	gchar	buf[32];
+	Battery	*bat;
 
-	if (!bat->alert)
+	if (!battery_list)
+		return;
+	bat = (Battery *) battery_list->data;
+
+	if (!bat_alert)
 		{
-		(*read_battery_data)();
 		alert_units_are_percent = alert_units_need_estimate_mode = FALSE;
-		snprintf(buf, sizeof(buf), "%s %d", _("Battery"), bat->id);
+
 		if (   using_percent
 			|| (bat->time_left == -1 && !enable_estimate)
 		   )
 			{
-			bat->alert = gkrellm_alert_create(NULL, buf,
+			bat_alert = gkrellm_alert_create(NULL, _("Battery"),
 					_("Battery Percent Limits"),
 					FALSE, TRUE, TRUE, 99, 0, 1, 10, 0);
 			alert_units_are_percent = TRUE;
 			}
 		else
 			{
-			bat->alert = gkrellm_alert_create(NULL, buf,
+			bat_alert = gkrellm_alert_create(NULL, _("Battery"),
 					_("Battery Minutes Remaining Limits"),
 					FALSE, TRUE, TRUE, 500, 0, 1, 10, 0);
 			if (bat->time_left == -1)
 				alert_units_need_estimate_mode = TRUE;
 			}
 		}
-	gkrellm_alert_trigger_connect(bat->alert,
-				cb_battery_alert_trigger, bat);
-	gkrellm_alert_command_process_connect(bat->alert,
-				cb_command_process, bat);
+	gkrellm_alert_config_connect(bat_alert, dup_battery_alert, NULL);
+
+	/* This alert is a master to be dupped and is itself never checked */
 	}
 
 
@@ -754,16 +819,18 @@ save_battery_config(FILE *f)
 	{
 	GList	*list;
 	Battery	*bat;
-	gchar	buf[16];
-	gint	n;
 
-	fprintf(f, "%s enable %d\n", BAT_CONFIG_KEYWORD, enable_battery);
-	fprintf(f, "%s estimate_time %d\n", BAT_CONFIG_KEYWORD,
-				enable_estimate);
-	fprintf(f, "%s estimate_time_discharge %.3f\n", BAT_CONFIG_KEYWORD,
-				estimate_runtime[0]);
-	fprintf(f, "%s estimate_time_charge %.3f\n", BAT_CONFIG_KEYWORD,
-				estimate_runtime[1]);
+	fprintf(f, "%s enable %d\n", BAT_CONFIG_KEYWORD, enable_each);
+	fprintf(f, "%s enable_composite %d\n", BAT_CONFIG_KEYWORD,
+					enable_composite);
+	fprintf(f, "%s estimate_time %d\n", BAT_CONFIG_KEYWORD, enable_estimate);
+
+	/* 2.1.15: scale saved float values to avoid decimal points in the config.
+	*/
+	fprintf(f, "%s estimate_time_discharge %.0f\n", BAT_CONFIG_KEYWORD,
+				estimate_runtime[0] * GKRELLM_FLOAT_FACTOR);
+	fprintf(f, "%s estimate_time_charge %.0f\n", BAT_CONFIG_KEYWORD,
+				estimate_runtime[1] * GKRELLM_FLOAT_FACTOR);
 	fprintf(f, "%s estimate_time_charge_model %d\n", BAT_CONFIG_KEYWORD,
 				estimate_model[1]);
 	fprintf(f, "%s full_cap_fallback %d\n", BAT_CONFIG_KEYWORD,
@@ -777,16 +844,17 @@ save_battery_config(FILE *f)
 					BAT_CONFIG_KEYWORD, launch.tooltip_comment);
 	fprintf(f, "%s alert_units_percent %d\n", BAT_CONFIG_KEYWORD,
 				alert_units_are_percent);
-	for (n = 0, list = battery_list; list; list = list->next, ++n)
+	for (list = battery_list; list; list = list->next)
 		{
 		bat = (Battery *) list->data;
-		if (!bat->real)
-			continue;
-		fprintf(f, "%s display_mode %d %d\n", BAT_CONFIG_KEYWORD,
-					bat->display_mode, n);
-		sprintf(buf, "BAT%d", n);
-		gkrellm_save_alertconfig(f, bat->alert, BAT_CONFIG_KEYWORD, buf);
+		if (bat == composite_battery)	/* Don't 2.1.16 backwards break */
+			fprintf(f, "%s display_mode_composite %d %d\n", BAT_CONFIG_KEYWORD,
+						bat->display_mode, bat->id);
+		else
+			fprintf(f, "%s display_mode %d %d\n", BAT_CONFIG_KEYWORD,
+						bat->display_mode, bat->id);
 		}
+	gkrellm_save_alertconfig(f, bat_alert, BAT_CONFIG_KEYWORD, NULL);
 	}
 
 static void
@@ -801,13 +869,21 @@ load_battery_config(gchar *arg)
 	if (sscanf(arg, "%31s %[^\n]", config, item) == 2)
 		{
 		if (!strcmp(config, "enable"))
-			sscanf(item, "%d", &enable_battery);
+			sscanf(item, "%d", &enable_each);
+		if (!strcmp(config, "enable_composite"))
+			sscanf(item, "%d", &enable_composite);
 		else if (!strcmp(config, "estimate_time"))
 			sscanf(item, "%d", &enable_estimate);
 		else if (!strcmp(config, "estimate_time_discharge"))
+			{
 			sscanf(item, "%f", &estimate_runtime[0]);
+			estimate_runtime[0] /= _GK.float_factor;
+			}
 		else if (!strcmp(config, "estimate_time_charge"))
+			{
 			sscanf(item, "%f", &estimate_runtime[1]);
+			estimate_runtime[1] /= _GK.float_factor;
+			}
 		else if (!strcmp(config, "estimate_time_charge_model"))
 			sscanf(item, "%d", &estimate_model[1]);
 		else if (!strcmp(config, "full_cap_fallback"))
@@ -818,29 +894,23 @@ load_battery_config(gchar *arg)
 			launch.command = g_strdup(item);
 		else if (!strcmp(config, "tooltip_comment"))
 			launch.tooltip_comment = g_strdup(item);
-		else if (!strcmp(config, "display_mode"))
+		else if (!strncmp(config, "display_mode", 12))
 			{
 			sscanf(item, "%d %d", &display_mode, &n);
-			bat = battery_nth(n);
-			bat->display_mode = display_mode;
+			if ((bat = battery_nth(n, FALSE)) != NULL)
+				bat->display_mode = display_mode;
 			}
 		else if (!strcmp(config, "alert_units_percent"))
 			sscanf(item, "%d", &using_percent);
 		else if (!strcmp(config, GKRELLM_ALERTCONFIG_KEYWORD))
 			{
-			if (!strncmp(item, "BAT", 3))
-				{
+			if (!strncmp(item, "BAT", 3))	/* Config compat musical chairs */
 				sscanf(item, "%32s %[^\n]", name, item1);
-				n = atoi(name + 3);
-				}
 			else
-				{
-				n = 0;		/* Compat with pre 2.1.3 */
 				strcpy(item1, item);
-				}
-			bat = battery_nth(n);
-			create_battery_alert(bat, using_percent);
-			gkrellm_load_alertconfig(&bat->alert, item1);
+			create_alert(using_percent);
+			gkrellm_load_alertconfig(&bat_alert, item1);
+			dup_battery_alert();
 			}
 		}
 	}
@@ -869,8 +939,8 @@ update_battery_panels(void)
 static void
 cb_set_alert(GtkWidget *button, Battery *bat)
 	{
-	create_battery_alert(bat, FALSE);
-	gkrellm_alert_config_window(&bat->alert);
+	create_alert(FALSE);
+	gkrellm_alert_config_window(&bat_alert);
 	}
 
 static void
@@ -892,12 +962,14 @@ cb_enable_estimate(GtkToggleButton *button, GtkWidget *box)
 			{
 			bat = (Battery *) list->data;
 			if (bat->alert && (!enable && alert_units_need_estimate_mode))
-				{
 				gkrellm_alert_destroy(&bat->alert);
-				gkrellm_config_message_dialog(_("GKrellM Battery"),
+			}
+		if (bat_alert && (!enable && alert_units_need_estimate_mode))
+			{
+			gkrellm_alert_destroy(&bat_alert);
+			gkrellm_config_message_dialog(_("GKrellM Battery"),
 					_("The Battery alert units are changed\n"
 					  "and the alert must be reconfigured."));
-				}
 			}
 		}
 	enable_estimate = enable;
@@ -921,19 +993,55 @@ cb_enable(GtkToggleButton *button, gpointer data)
 	{
 	GList	*list;
 	Battery	*bat;
+	gint	which  = GPOINTER_TO_INT(data);
+
+	if (which == 0)
+		enable_composite = enable_each = button->active;
+	else if (which == 1)
+		enable_each = button->active;
+	else if (which == 2)
+		enable_composite = button->active;
 
-	enable_battery = button->active;
 	for (list = battery_list; list; list = list->next)
 		{
 		bat = (Battery *) list->data;
-		bat->enabled = enable_battery;
-		if (enable_battery)
+		if (bat == composite_battery)
+			bat->enabled = enable_composite;
+		else
+			bat->enabled = enable_each;
+
+		if (bat->enabled)
 			{
 			gkrellm_panel_show(bat->panel);
 			update_battery_panel(bat);
 			}
 		else
+			{
+			gkrellm_reset_alert(bat->alert);
 			gkrellm_panel_hide(bat->panel);
+			}
+		}
+	if (composite_battery)
+		{
+		gkrellm_remove_launcher(&launch);
+
+		if (composite_battery->enabled)
+			{
+			gkrellm_setup_decal_launcher(composite_battery->panel,
+						&launch, composite_battery->time_decal);
+			launch_battery = composite_battery;
+			}
+		else
+			{
+			bat = battery_nth(0, FALSE);
+			if (bat && bat->enabled)
+				{
+				gkrellm_setup_decal_launcher(bat->panel,
+						&launch, bat->time_decal);
+				launch_battery = bat;
+				}
+			}
+
 		}
 	spacer_visibility();
 	}
@@ -958,13 +1066,10 @@ cb_poll_interval(GtkWidget *entry, GtkSpinButton *spin)
 static void 
 cb_launch_entry(GtkWidget *widget, gpointer data)
 	{
-	Battery	*bat;
-
-	if (!battery_list)
+	if (!launch_battery)
 		return;
-	bat = (Battery *) battery_list->data;
-	gkrellm_apply_launcher(&launch_entry, &tooltip_entry, bat->panel,
-				&launch, gkrellm_launch_button_cb);
+	gkrellm_apply_launcher(&launch_entry, &tooltip_entry,
+				launch_battery->panel, &launch, gkrellm_launch_button_cb);
 	}
 
 
@@ -986,6 +1091,16 @@ N_("For some charging systems battery capacity rises exponentially, which\n"
 "means the simple linear model will grossly underestimate the time to 100%.\n"
 "Select the exponential model for more accuracy in this case.\n"),
 "\n",
+"<b>",
+N_("Alerts"),
+"\n",
+N_("Substitution variables may be used in alert commands.\n"),
+N_("\t$p    battery percent level.\n"),
+N_("\t$t    battery time left.\n"),
+N_("\t$n    battery number.\n"),
+N_("\t$o    online state (boolean).\n"),
+N_("\t$c    charging state (boolean).\n"),
+"\n",
 N_("<h>Mouse Button Actions:\n"),
 N_("<b>\tLeft "),
 N_(" click on the charging state decal to toggle the display mode\n"
@@ -997,11 +1112,8 @@ N_(" clicking anywhere on the Battery panel also toggles the display mode.\n")
 static void
 create_battery_tab(GtkWidget *tab_vbox)
 	{
-	GtkWidget	*tabs, *table, *vbox, *vbox1,
+	GtkWidget	*tabs, *table, *vbox, *vbox1, *vbox2,
 				*hbox, *hbox2, *text;
-	GtkWidget	*image, *button, *label;
-	GList		*list;
-	gchar		buf[32];
 	gint		i;
 
 	tabs = gtk_notebook_new();
@@ -1009,43 +1121,57 @@ create_battery_tab(GtkWidget *tab_vbox)
 	gtk_box_pack_start(GTK_BOX(tab_vbox), tabs, TRUE, TRUE, 0);
 
 /* -- Setup tab */
-	vbox = gkrellm_gtk_framed_notebook_page(tabs, _("Options"));
+	vbox = gkrellm_gtk_notebook_page(tabs, _("Options"));
+	vbox = gkrellm_gtk_framed_vbox(vbox, NULL, 2, TRUE, 10, 6);
 
-	gkrellm_gtk_check_button_connected(vbox, NULL,
-			enable_battery, FALSE, FALSE, 10,
-			cb_enable, NULL,
-			_("Enable Battery"));
+	if (composite_battery && n_batteries > 0)
+		{
+		vbox1 = gkrellm_gtk_category_vbox(vbox, _("Enable"), 2, 2, TRUE);
+
+		gkrellm_gtk_check_button_connected(vbox1, NULL,
+				enable_composite, FALSE, FALSE, 0,
+				cb_enable, GINT_TO_POINTER(2),
+				_("Composite Battery"));
+		gkrellm_gtk_check_button_connected(vbox1, NULL,
+				enable_each, FALSE, FALSE, 0,
+				cb_enable, GINT_TO_POINTER(1),
+				_("Real Batteries"));
+		}
+	else
+		gkrellm_gtk_check_button_connected(vbox, NULL,
+				enable_each, FALSE, FALSE, 10,
+				cb_enable, GINT_TO_POINTER(0),
+				_("Enable Battery"));
+
+	vbox2 = gtk_vbox_new(FALSE, 0);
+	gtk_box_pack_start(GTK_BOX(vbox), vbox2, FALSE, FALSE, 0);
 
 	vbox1 = gtk_vbox_new(FALSE, 0);
-	gkrellm_gtk_check_button_connected(vbox, NULL, 
-			enable_estimate, FALSE, FALSE, 0,
+	gkrellm_gtk_check_button_connected(vbox2, NULL, 
+			enable_estimate, FALSE, FALSE, 2,
 			cb_enable_estimate, vbox1, 
 			_("Display estimated time remaining and time to charge"));
 	gtk_widget_set_sensitive(vbox1, enable_estimate ? TRUE : FALSE);
-	gtk_box_pack_start(GTK_BOX(vbox), vbox1, FALSE, FALSE, 0);
+	gtk_box_pack_start(GTK_BOX(vbox2), vbox1, FALSE, FALSE, 0);
 
-	hbox2 = gtk_hbox_new(FALSE, 10);
-	gkrellm_gtk_spin_button(hbox2, &estimate_runtime_spin_button[0], 
+	vbox1 = gkrellm_gtk_category_vbox(vbox1, NULL, 0, 0, TRUE);
+	gkrellm_gtk_spin_button(vbox1, &estimate_runtime_spin_button[0], 
 			estimate_runtime[0], 0.1, 24, 0.1, 1.0, 1, 55,
 			cb_runtime, GINT_TO_POINTER(1), FALSE,
 			_("Total battery run time in hours"));
-	gtk_box_pack_start(GTK_BOX(vbox1), hbox2, FALSE, FALSE, 0);
-
-	hbox2 = gtk_hbox_new(FALSE, 10);
-	gkrellm_gtk_spin_button(hbox2, &estimate_runtime_spin_button[1], 
+	gkrellm_gtk_spin_button(vbox1, &estimate_runtime_spin_button[1], 
 			estimate_runtime[1], 0.1, 24, 0.1, 1.0, 1, 55,
 			cb_runtime, GINT_TO_POINTER(2), FALSE,
 			_("Total battery charge time in hours"));
 
-	gkrellm_gtk_check_button_connected(hbox2, &estimate_model_button[1], 
+	gkrellm_gtk_check_button_connected(vbox1, &estimate_model_button[1], 
             estimate_model[1], FALSE, FALSE, 0,
 			cb_estimate_model, GINT_TO_POINTER(1),
 			_("Exponential charge model"));
-	gtk_box_pack_start(GTK_BOX(vbox1), hbox2, FALSE, FALSE, 0);
 
 	if (!_GK.client_mode)
 		{
-		hbox2 = gtk_hbox_new(FALSE, 10);
+		hbox2 = gtk_hbox_new(FALSE, 0);
 		gkrellm_gtk_spin_button(hbox2, NULL,
 				(gfloat) poll_interval, 1, 3600, 1, 10, 0, 55,
 				cb_poll_interval, NULL, FALSE,
@@ -1054,28 +1180,11 @@ create_battery_tab(GtkWidget *tab_vbox)
 		}
 
 	vbox = gkrellm_gtk_framed_notebook_page(tabs, _("Setup"));
+
 	hbox = gtk_hbox_new(FALSE, 0);
-	gtk_box_pack_start(GTK_BOX(vbox), hbox, FALSE, FALSE, 5);
-
-	for (i = 0, list = battery_list; list; list = list->next, ++i)
-		{
-		hbox2 = gtk_hbox_new(FALSE, 0);
-		gtk_container_set_border_width(GTK_CONTAINER(hbox2), 2);
-		image = gtk_image_new_from_pixbuf(gkrellm_alert_pixbuf());
-		snprintf(buf, sizeof(buf), "%s %d", _("Alerts"), i);
-		label = gtk_label_new(buf);
-		gtk_box_pack_start(GTK_BOX(hbox2), image, FALSE, FALSE, 3);
-		gtk_box_pack_start(GTK_BOX(hbox2), label, FALSE, FALSE, 3);
-		button = gtk_button_new();
-		g_signal_connect(G_OBJECT(button), "clicked",
-					G_CALLBACK(cb_set_alert), (Battery *) list->data);
-		gtk_widget_show_all(hbox2);
-		gtk_container_add(GTK_CONTAINER(button), hbox2);
-		gtk_box_pack_start(GTK_BOX(hbox), button, FALSE, FALSE, 4);
-
-//		gkrellm_gtk_button_connected(hbox, NULL, FALSE, FALSE, 0,
-//				cb_set_alert, NULL, _("Alerts"));
-		}
+	gtk_box_pack_start(GTK_BOX(vbox), hbox, FALSE, FALSE, 8);
+	gkrellm_gtk_alert_button(hbox, NULL, FALSE, FALSE, 4, TRUE,
+				cb_set_alert, NULL);
 
 	vbox1 = gkrellm_gtk_framed_vbox_end(vbox, _("Launch Commands"),
 			4, FALSE, 0, 2);
@@ -1121,8 +1230,6 @@ static GkrellmMonitor	monitor_battery =
 GkrellmMonitor *
 init_battery_monitor(void)
 	{
-	enable_battery = FALSE;
-	enable_estimate = FALSE;	/* use the BIOS value */
 	estimate_runtime[0] =  1.5;	/* 1.5 hour battery */
 	estimate_runtime[1] =	3.0;	/* 3 hour recharge */
 	if (_GK.client_mode)
@@ -1133,6 +1240,9 @@ init_battery_monitor(void)
 	style_id = gkrellm_add_meter_style(&monitor_battery, BATTERY_STYLE_NAME);
 	mon_battery = &monitor_battery;
 	if (setup_battery_interface())
+		{
+		(*read_battery_data)();
 		return &monitor_battery;
+		}
 	return NULL;
 	}
