@@ -1625,36 +1625,29 @@ parse_monitor_config_keyword(gchar *line)
 	{
 	GList			*list;
 	GkrellmMonitor	*mon;
-	gchar			*s;
-	gint			n;
+	gchar			*keyword;
+	gboolean		result = FALSE;
 
-	s = line;
-	while (*s && *s != ' ' && *s != '\t')
-		++s;
-	if (!*s || *s == '\n')
-		return FALSE;
-
-	n = s - line;
-	if (n <= 0)
-		return FALSE;
-
-	if (!strncmp("apm", line, n))	/* Fix APM->Battery monitor name change */
+	keyword = gkrellm_dup_token(&line, NULL);
+	if (!*keyword)
 		{
-		line = "battery";
-		n = 7;
+		g_free(keyword);
+		return FALSE;
 		}
+
 	for (list = gkrellm_monitor_list; list; list = list->next)
 		{
 		mon = (GkrellmMonitor *) list->data;
-		if (!mon->config_keyword || strncmp(mon->config_keyword, line, n))
+		if (!mon->config_keyword || strcmp(mon->config_keyword, keyword))
 			continue;
-		while (*s == ' ' || *s == '\t')
-			++s;
-		if (*s && mon->load_user_config && mon->privat->enabled)
-			(*(mon->load_user_config))(s);
-		return TRUE;
+		while (*line == ' ' || *line == '\t')
+			++line;
+		if (*line && mon->load_user_config && mon->privat->enabled)
+			(*(mon->load_user_config))(line);
+		result = TRUE;
 		}
-	return FALSE;
+	g_free(keyword);
+	return result;
 	}
 
 static gboolean
