@@ -111,6 +111,8 @@ struct	GkrellmConfig
 	gboolean	track_gtk_theme_name;
 	gchar		*default_track_theme;
 
+	gchar		*session_id;
+
 	gint		update_HZ;
 	gint		chart_width;
 	gboolean	save_position,
@@ -299,6 +301,7 @@ void load_plugin_monitors(void);
 
 void	create_plugin_config(GtkWidget *);
 void	close_plugins_config(void);
+void	gkrellm_menu_popup(void);
 
 GkrellmMonitor *init_host_monitor(void);
 GkrellmMonitor *init_cal_monitor(void);
