@@ -121,6 +121,7 @@ void		gkrellm_chartconfig_fixed_grids_connect(GkrellmChartconfig *,
 gint		gkrellm_get_chartconfig_height(GkrellmChartconfig *);
 void		gkrellm_chartconfig_height_connect(GkrellmChartconfig *,
 						void (*fn)(), gpointer);
+void		gkrellm_chartconfig_callback_block(GkrellmChartconfig *, gboolean);
 void		gkrellm_save_chartconfig(FILE *, GkrellmChartconfig *,
 						gchar *, gchar *);
 void		gkrellm_load_chartconfig(GkrellmChartconfig **, gchar *, gint);
@@ -176,8 +177,12 @@ void		gkrellm_insert_krell_nth(GkrellmPanel *, GkrellmKrell *, gint);
 
   /* Decal and Decalbutton functions
   */
-GkrellmDecal *gkrellm_create_decal_text(GkrellmPanel *p, gchar *,
-						GkrellmTextstyle *, GkrellmStyle *, gint, gint, gint);
+GkrellmDecal *gkrellm_create_decal_text(GkrellmPanel *p, gchar *string,
+						GkrellmTextstyle *ts, GkrellmStyle *style,
+						gint x, gint y, gint w);
+GkrellmDecal *gkrellm_create_decal_text_with_height(GkrellmPanel *p,
+						GkrellmTextstyle *ts, GkrellmStyle *style,
+						gint x, gint y, gint w, gint h, gint y_baseline);
 GkrellmDecal *gkrellm_create_decal_pixmap(GkrellmPanel *, GdkPixmap *,
 						GdkBitmap *, gint, GkrellmStyle *, gint, gint);
 GkrellmDecal *gkrellm_make_scaled_decal_pixmap(GkrellmPanel *p,
@@ -187,6 +192,10 @@ GkrellmDecal *gkrellm_make_scaled_decal_pixmap(GkrellmPanel *p,
 void		gkrellm_draw_decal_pixmap(GkrellmPanel *, GkrellmDecal *, gint);
 void		gkrellm_draw_decal_text(GkrellmPanel *, GkrellmDecal *, gchar *,
 						gint);
+void		gkrellm_decal_text_clear(GkrellmDecal *d);
+void		gkrellm_decal_text_insert(GkrellmDecal *d, gchar *s,
+						GkrellmTextstyle *ts, gint x_off, gint y_off);
+
 void		gkrellm_draw_decal_on_chart(GkrellmChart *, GkrellmDecal *,
 						gint, gint);
 void		gkrellm_move_decal(GkrellmPanel *, GkrellmDecal *, gint, gint);
@@ -293,6 +302,7 @@ void		gkrellm_setup_launcher(GkrellmPanel *, GkrellmLauncher *, gint,
 						gint);
 void		gkrellm_setup_decal_launcher(GkrellmPanel *, GkrellmLauncher *,
 						GkrellmDecal *);
+void		gkrellm_remove_launcher(GkrellmLauncher *launch);
 void		gkrellm_configure_tooltip(GkrellmPanel *, GkrellmLauncher *);
 void		gkrellm_launch_button_cb(GkrellmDecalbutton *);
 void		gkrellm_disable_plugin_connect(GkrellmMonitor *, void (*func)());
@@ -330,6 +340,8 @@ void		gkrellm_reset_panel_alerts(GkrellmPanel *);
 void		gkrellm_freeze_alert(GkrellmAlert *);
 void		gkrellm_thaw_alert(GkrellmAlert *);
 gboolean	gkrellm_alert_is_activated(GkrellmAlert *alert);
+void		gkrellm_alert_get_alert_state(GkrellmAlert *alert,
+						gboolean *alarm_state, gboolean *warn_state);
 void		gkrellm_alert_trigger_connect(GkrellmAlert *, void (*func)(),
 						gpointer);
 void		gkrellm_alert_stop_connect(GkrellmAlert *, void (*func)(),
@@ -354,6 +366,26 @@ void		gkrellm_alert_delay_config(GkrellmAlert *alert, gint step,
 						gint high, gint low);
 void		gkrellm_alert_commands_config(GkrellmAlert *alert,
 						gboolean alarm, gboolean warn);
+  /* Alert plugin API
+  */
+GkrellmAlertPlugin	*gkrellm_alert_plugin_add(GkrellmMonitor *mon,
+						gchar *name);
+void		gkrellm_alert_plugin_connect(GkrellmAlertPlugin *gap,
+            			void (*alarm_func)(), void (*warn_func)(),
+						void (*update_func)(), void (*destroy_func)());
+void		gkrellm_alert_plugin_config_connect(GkrellmAlertPlugin *gap,
+						gchar *tab_name,
+            			void (*config_create_func)(), void (*config_done_func),
+            			void (*config_save_func)(),void (*config_load_func)());
+gchar		*gkrellm_alert_plugin_config_get_id_string(GkrellmAlert *alert);
+void		gkrellm_alert_plugin_alert_attach(GkrellmAlertPlugin *gap,
+            			GkrellmAlert *alert, gpointer data);
+void		gkrellm_alert_plugin_alert_detach(GkrellmAlertPlugin *gap,
+						GkrellmAlert *alert);
+gpointer	gkrellm_alert_plugin_get_data(GkrellmAlertPlugin *gap,
+						GkrellmAlert *alert);
+void		gkrellm_alert_plugin_command_process(GkrellmAlert *alert,
+						gchar *src, gchar *dst, gint dst_size);
 
 
   /* GKrellM Styles and Textstyles
@@ -443,6 +475,9 @@ GtkWidget	*gkrellm_gtk_framed_vbox(GtkWidget *, gchar *, gint, gboolean,
 						gint, gint);
 GtkWidget	*gkrellm_gtk_framed_vbox_end(GtkWidget *, gchar *, gint, gboolean,
 						gint, gint);
+GtkWidget	*gkrellm_gtk_category_vbox(GtkWidget *box, gchar *category_header,
+        				gint header_pad, gint box_pad, gboolean pack_start);
+
 GtkWidget	*gkrellm_gtk_scrolled_text_view(GtkWidget *, GtkWidget **,
 						GtkPolicyType, GtkPolicyType);
 void		gkrellm_gtk_text_view_append_strings(GtkWidget *, gchar **, gint);
@@ -454,6 +489,7 @@ void		gkrellm_gtk_text_view_append(GtkWidget *, gchar *);
 gchar		*gkrellm_homedir(void);
 gboolean	gkrellm_dup_string(gchar **, gchar *);
 gboolean	gkrellm_locale_dup_string(gchar **dst, gchar *src, gchar **locale);
+gchar		*gkrellm_dup_token(gchar **string, gchar *delimeters);
 gchar		*gkrellm_make_config_file_name(gchar *, gchar *);
 gchar		*gkrellm_make_data_file_name(gchar *, gchar *);
 struct tm	*gkrellm_get_current_time(void);
