@@ -2391,7 +2391,7 @@ gkrellm_open_config_window(GkrellmMonitor *mon)
 	{
 	GtkTreePath	*path;
 
-	if (!mon || !mon->create_config)
+	if (!mon || !mon->create_config || _GK.no_config)
 		return;
 	create_config_window();
 	if (MONITOR_ID(mon) == MON_PLUGIN)
@@ -2429,6 +2429,7 @@ static GtkItemFactoryEntry	debug_items[] =
 {"/-",				    NULL,	NULL,					0, "<Separator>"},
 {N_("/Theme prev"), "<control>Page_Up",	cb_load_theme, THEME_PREV, "<Item>"},
 {N_("/Theme next"), "<control>Page_Down", cb_load_theme, THEME_NEXT, "<Item>"},
+{"/Menu Popup",     "F2",   gkrellm_menu_popup,     0, "<Item>"},
 {"/Reload Theme",	"F5",	cb_load_theme,	THEME_RELOAD, "<Item>"},
 {"/Scale Theme Up",	"F6",	cb_load_theme,	THEME_SCALE_UP, "<Item>"},
 {"/Scale Theme Dn",	"F7",	cb_load_theme,	THEME_SCALE_DOWN, "<Item>"}
