@@ -33,18 +33,44 @@ static GkrellmPanel		*host;
 static GkrellmDecal		*decal_host;
 static GkrellmDecal		*decal_sysname;
 static GkrellmAlert		*server_alert;
+static GkrellmDecalbutton *sysname_mode_button;
 
-static GtkWidget	*host_vbox;
+static GtkWidget		*host_vbox;
 
-static gint			style_id;
+static gint				style_id;
 
-static gboolean		hostname_visible,
-					hostname_short,
-					system_name_visible;
+static gboolean			hostname_visible,
+						hostname_short,
+						system_name_visible,
+						hostname_can_shorten;
+
+gint					system_name_mode = 1;
+
+typedef struct
+	{
+	gchar				*string;	/* String to draw on a decal	*/
+	GkrellmTextstyle	*ts;		/* using this textstyle			*/
+	gint				yoff,
+						xoff,
+						w;			/* Pixel width of string using ts */
+	gboolean			reduced;	/* TRUE if default string/font won't fit */
+	}
+	DecalText;
+
+static DecalText	host_dtext,
+					system_dtext,
+					kname_dtext,
+					kversion_dtext;
 
 static gchar		*hostname,
 					*system_name;
 
+gboolean
+gkrellm_hostname_can_shorten(void)
+	{
+	return hostname_can_shorten;
+	}
+
 static gint
 host_expose_event(GtkWidget *widget, GdkEventExpose *ev)
 	{
@@ -59,59 +85,170 @@ host_expose_event(GtkWidget *widget, GdkEventExpose *ev)
 
 
 static void
-draw_hostname(void)
+pick_textstyle(GkrellmDecal *d, DecalText *dtext)
 	{
 	GkrellmTextstyle	*ts;
-	gchar		*s, buf[128];
-	gint		w;
+	gint				w;
 
-	if (decal_host)
+	g_free(dtext->ts);
+	ts = gkrellm_meter_textstyle(style_id);
+	dtext->ts = gkrellm_copy_textstyle(ts);	/* May change only font */
+	w = gkrellm_gdk_string_width(ts->font, dtext->string);
+	if (w > d->w)
 		{
-		ts = gkrellm_meter_textstyle(style_id);
-		strncpy(buf, hostname, sizeof(buf) - 1);
-		buf[sizeof(buf) - 1] = '\0';
-		if (_GK.hostname_short)		/* XXX */
-			{
-			s = strchr(buf, (int) '.');
-			if (s)
-				*s = '\0';
-			}
-		w = gkrellm_gdk_string_width(ts->font, buf);
-		if (w > decal_host->w)
-			{
-			ts = gkrellm_meter_alt_textstyle(style_id);
-			w = gkrellm_gdk_string_width(ts->font, buf);
-			}
-		decal_host->x_off = (decal_host->w - w) / 2;
-		if (decal_host->x_off < 0)
-			decal_host->x_off = 0;
-		decal_host->text_style.font = ts->font;
-		gkrellm_draw_decal_text(host, decal_host, buf, -1);
+		ts = gkrellm_meter_alt_textstyle(style_id);
+		w = gkrellm_gdk_string_width(ts->font, dtext->string);
+		dtext->reduced = TRUE;
 		}
-	if (decal_sysname)
+	dtext->w = w;
+	dtext->ts->font = ts->font;
+	dtext->xoff = (d->w - w) / 2;
+	if (dtext->xoff < 0)
+		dtext->xoff = 0;
+	}
+
+static void
+prune(gchar **name, gchar *s, gboolean split, gboolean only_vowels)
+	{
+	gchar *dst, *d;
+
+	dst = g_new(gchar, strlen(s) + 1);
+	for (d = dst ; *s ; ++s)
 		{
-		ts = gkrellm_meter_textstyle(style_id);
-		w = gkrellm_gdk_string_width(ts->font, system_name);
-		if (w > decal_sysname->w)
-			{
-			ts = gkrellm_meter_alt_textstyle(style_id);
-			w = gkrellm_gdk_string_width(ts->font, system_name);
-			}
-		decal_sysname->x_off = (decal_sysname->w - w) / 2;
-		if (decal_sysname->x_off < 0)
-			decal_sysname->x_off = 0;
-		decal_sysname->text_style.font = ts->font;
-		gkrellm_draw_decal_text(host, decal_sysname, system_name, -1);
+		if (split && *s == ' ')
+			break;
+		if (!only_vowels)
+			continue;
+		if (   (*s != 'a' && *s != 'e' && *s != 'i' && *s != 'o' && *s != 'u')
+			|| !*(s + 1)	/* Don't prune a trailing vowel */
+		   )
+			*d++ = *s;
 		}
-	if (decal_host || decal_sysname)
-		gkrellm_draw_panel_layers(host);
+	if (*s)
+		strcpy(d, only_vowels ? s : s + 1);
+	else
+		*d = '\0';
+	g_free(*name);
+	*name = dst;
+	}
+
+static void
+setup_sysname(void)
+	{
+	if (!decal_sysname)
+		return;
+
+	g_free(system_dtext.string);
+	system_dtext.string = g_strdup(system_name);
+	system_dtext.reduced = FALSE;
+	pick_textstyle(decal_sysname, &system_dtext);
+	if (system_dtext.w > decal_sysname->w)
+		{
+		system_dtext.reduced = TRUE;
+		prune(&system_dtext.string, system_name, TRUE, TRUE);
+		pick_textstyle(decal_sysname, &system_dtext);
+		if (system_dtext.w > decal_sysname->w)
+			{
+			prune(&system_dtext.string, system_name, FALSE, TRUE);
+			pick_textstyle(decal_sysname, &system_dtext);
+			if (system_dtext.w > decal_sysname->w)
+				{
+				prune(&system_dtext.string, system_name, TRUE, FALSE);
+				pick_textstyle(decal_sysname, &system_dtext);
+				}
+			}
+		}
+	kname_dtext.reduced = FALSE;
+	pick_textstyle(decal_sysname, &kname_dtext);
+	kname_dtext.yoff = 0;
+
+	kversion_dtext.reduced = FALSE;
+	pick_textstyle(decal_sysname, &kversion_dtext);
+	kversion_dtext.yoff = decal_sysname->h;
+	}
+
+static void
+draw_hostname(void)
+	{
+	gchar		*s, buf[128];
+
+	if (!decal_host)
+		return;
+
+	strncpy(buf, hostname, sizeof(buf) - 1);
+	buf[sizeof(buf) - 1] = '\0';
+	if (hostname_can_shorten && _GK.hostname_short)		/* XXX */
+		{
+		s = strchr(buf, (int) '.');
+		if (s)
+			*s = '\0';
+		}
+	host_dtext.string = buf;
+	pick_textstyle(decal_host, &host_dtext);
+
+	decal_host->x_off = host_dtext.xoff;
+	decal_host->text_style.font = host_dtext.ts->font;
+	gkrellm_draw_decal_text(host, decal_host, host_dtext.string, -1);
+	}
+
+static void
+draw_sysname(void)
+	{
+	DecalText	*dtext0, *dtext1 = NULL;
+
+	if (!decal_sysname)
+		return;
+
+	if (system_name_mode == 0 || !system_dtext.reduced)
+		dtext0 = &system_dtext;
+	else
+		{
+		dtext0 = &kname_dtext;
+		dtext1 = &kversion_dtext;
+		}
+			
+	gkrellm_decal_text_clear(decal_sysname);
+	gkrellm_decal_text_insert(decal_sysname, dtext0->string, dtext0->ts,
+				dtext0->xoff, dtext0->yoff);
+	if (dtext1)
+		gkrellm_decal_text_insert(decal_sysname, dtext1->string, dtext1->ts,
+					dtext1->xoff, dtext1->yoff);
 	}
 
 void
 update_host(void)
 	{
-	gint		connect_state;
-	static gint	reconnect_timeout;
+	gint		connect_state, delta, step;
+	gint		hz = gkrellm_update_HZ();
+	static gint	reconnect_timeout, y_target, asym;
+
+	if (decal_sysname && system_name_mode == 1 && system_dtext.reduced)
+		{
+		if (GK.two_second_tick && y_target != 0)
+			{
+			y_target = 0;
+			asym = 3;		/* 2 secs name, 6 secs version */
+			}
+		else if (GK.two_second_tick && y_target == 0  && --asym <= 0)
+			y_target = decal_sysname->h;
+
+		delta = y_target - kversion_dtext.yoff;
+		if (delta != 0)
+			{
+			step = (delta < 0) ? -1 : 1;
+			if (hz < 10)
+				{
+				if (hz < 5)
+					step = delta;
+				else if (delta > 1 || delta < -1)
+					step *= 2;
+				}
+			kname_dtext.yoff += step;
+			kversion_dtext.yoff += step;
+			draw_sysname();
+			gkrellm_draw_panel_layers(host);
+			}
+		}
 
 	if (!_GK.client_mode || !GK.second_tick)
 		return;
@@ -207,6 +344,17 @@ create_server_alert(void)
 				cb_command_process, NULL);
 	}
 
+static void
+cb_sysname_mode(GkrellmDecalbutton *button, gpointer data)
+	{
+	system_name_mode = !system_name_mode;
+	kname_dtext.yoff = 0;
+	kversion_dtext.yoff = decal_sysname->h;
+	draw_sysname();
+	gkrellm_draw_panel_layers(host);
+	gkrellm_config_modified();
+	}
+
 static void
 create_hostname(GtkWidget *vbox, gint first_create)
 	{
@@ -218,16 +366,8 @@ create_hostname(GtkWidget *vbox, gint first_create)
 	host_vbox = vbox;
 
 	if (_GK.client_mode)
-		{
-		hostname = _GK.server_hostname;
-		system_name = _GK.server_sysname;
 		create_server_alert();
-		}
-	else
-		{
-		hostname = gkrellm_sys_get_host_name();
-		system_name = gkrellm_sys_get_system_name();
-		}
+
 	style = gkrellm_meter_style(style_id);
 
 	decal_host = decal_sysname = NULL;
@@ -261,7 +401,24 @@ create_hostname(GtkWidget *vbox, gint first_create)
 	hostname_visible = _GK.enable_hostname;
 	hostname_short = _GK.hostname_short;
 	system_name_visible = _GK.enable_system_name;
+	setup_sysname();
 	draw_hostname();
+	draw_sysname();
+	if (decal_host || decal_sysname)
+		gkrellm_draw_panel_layers(host);
+	if (decal_sysname && system_dtext.reduced)
+		{
+		l = decal_sysname->h * 4 / 5;
+		sysname_mode_button = gkrellm_make_scaled_button(host, NULL,
+					cb_sysname_mode, NULL, TRUE, TRUE,
+					0, 0, 0,	/* Use builtin images */
+					gkrellm_chart_width() - l,
+					decal_sysname->y + decal_sysname->h - l,
+					l, l);
+		}
+	else
+		sysname_mode_button = NULL;
+
 	if (!decal_host && !decal_sysname && !_GK.decorated)
 		{
 		gkrellm_panel_hide(host);
@@ -289,10 +446,13 @@ gkrellm_apply_hostname_config(void)
 		gkrellm_alert_destroy(&server_alert);
 		create_hostname(host_vbox, TRUE);
 		}
-	else if (_GK.hostname_short != hostname_short)
+	else if (hostname_can_shorten && _GK.hostname_short != hostname_short)
 		{
 		hostname_short = _GK.hostname_short;
 		draw_hostname();
+		draw_sysname();
+		if (decal_host || decal_sysname)
+			gkrellm_draw_panel_layers(host);
 		}
 	}
 
@@ -305,6 +465,7 @@ cb_gkrellmd_disconnect_alert(GtkWidget *button, gpointer data)
 static void
 save_host_config(FILE *f)
 	{
+	fprintf(f, "%s sysname_mode %d\n", HOST_CONFIG_KEYWORD, system_name_mode);
 	if (_GK.client_mode && server_alert)
 		gkrellm_save_alertconfig(f, server_alert, HOST_CONFIG_KEYWORD, NULL);
 	}
@@ -315,15 +476,16 @@ load_host_config(gchar *arg)
 	gchar	config[32], item[CFG_BUFSIZE];
 	gint	n;
 
-	n = sscanf(arg, "%31s %[^\n]", config, item);
-	if (n == 2)
+	if ((n = sscanf(arg, "%31s %[^\n]", config, item)) != 2)
+		return;
+
+	if (!strcmp(config, "sysname_mode"))
+		sscanf(item, "%d", &system_name_mode);
+	else if (!strcmp(config, GKRELLM_ALERTCONFIG_KEYWORD))
 		{
-		if (!strcmp(config, GKRELLM_ALERTCONFIG_KEYWORD))
-			{
-			if (!server_alert)
-				create_server_alert();
-			gkrellm_load_alertconfig(&server_alert, item);
-			}
+		if (!server_alert)
+			create_server_alert();
+		gkrellm_load_alertconfig(&server_alert, item);
 		}
 	}
 
@@ -353,7 +515,25 @@ static GkrellmMonitor	monitor_host =
 GkrellmMonitor *
 init_host_monitor(void)
 	{
+	gchar	**parts;
+
 	style_id = gkrellm_add_meter_style(&monitor_host, HOST_STYLE_NAME);
+
+	if (_GK.client_mode)
+		{
+		hostname = _GK.server_hostname;
+		system_name = _GK.server_sysname;
+		}
+	else
+		{
+		hostname = gkrellm_sys_get_host_name();
+		system_name = gkrellm_sys_get_system_name();
+		}
+	parts = g_strsplit(system_name, " ", 2);
+	kname_dtext.string = parts[0];
+	kversion_dtext.string = parts[1];
+	hostname_can_shorten = strchr(hostname, (int) '.') ? TRUE : FALSE;
+
 	mon_host = &monitor_host;
 	return &monitor_host;
 	}
