@@ -564,6 +564,13 @@ gkrellm_motion(GtkWidget *widget, GdkEventMotion *ev, gpointer data)
 		}
 	}
 
+void
+gkrellm_menu_popup(void)
+	{
+	gtk_menu_popup(GTK_MENU(item_factory->widget), NULL, NULL, NULL, NULL,
+					0, gtk_get_current_event_time());
+	}
+
 static void
 top_frame_button_release(GtkWidget *widget, GdkEventButton *ev, gpointer data)
 	{
@@ -1942,6 +1949,8 @@ main(gint argc, gchar **argv)
 			_GK.theme_path = g_strdup(argv[++i]);
 			_GK.command_line_theme = g_strdup(_GK.theme_path);
 			}
+		else if (!strcmp(s, "sm-client-id") && i < argc - 1)
+			_GK.session_id = g_strdup(argv[++i]);
 		else if ((!strcmp(s, "s") || !strcmp(s, "server")) && i < argc - 1)
 			{
 			_GK.server = g_strdup(argv[++i]);
