@@ -2548,7 +2548,7 @@ create_net_tab(GtkWidget *tab_vbox)
 	gkrellm_gtk_check_button_connected(vbox, &net_timer_seconds_button,
 				timer_seconds, FALSE, FALSE, 0,
 				cb_timer_seconds, NULL,
-				_("Show seconds in timer button"));
+				_("Show seconds"));
 	hbox = gtk_hbox_new (FALSE, 3);
 	gtk_container_set_border_width(GTK_CONTAINER(hbox), 0);
 	gtk_box_pack_start(GTK_BOX(vbox), hbox, FALSE, FALSE, 50);
