@@ -29,8 +29,8 @@
 |		so sensor[1,2,3] can be set correctly in sensors.conf.
 */
 
-  /* On Linux, the sensor basename includes the parent chip directory, so
-  |  "lm78/temp" will be a basename, and not just "temp".  This is to
+  /* On Linux, the sensor id_name includes the parent chip directory, so
+  |  "lm78/temp" will be a id_name, and not just "temp".  This is to
   |  allow unique identification in case of multiple "temp" files.
   |  ie, more than 1 chip directory, each with a "temp" file.
   */
@@ -41,8 +41,7 @@ typedef struct _sensor
 	gchar		*name_locale;	/* gdk_draw compat */
 	gchar		*default_label;	/* Only voltages have default labels */
 	gchar		*path;			/* Pathname to sensor data or device file */
-	gchar		*dir;			/* Sensor directory */
-	gchar		*basename;
+	gchar		*id_name;		/* Unique sensor identifier for config */
 	gint		type;
 
 	gint		id;
@@ -115,28 +114,27 @@ setup_sensor_interface(void)
 
 
 void
-gkrellm_sensors_add_sensor(gint type, gchar *dir, gchar *basename,
+gkrellm_sensors_add_sensor(gint type, gchar *sensor_path, gchar *id_name,
 		gint id, gint iodev, gint inter,
 		gfloat factor, gfloat offset, gchar *vref, gchar *default_label)
 	{
 	Sensor	*sensor;
 	gchar	*r;
 
-	if (!basename || !*basename || type < 0 || type > 2)
+	if (!id_name || !*id_name || type < 0 || type > 2)
 		return;
 
 	sensor = g_new0(Sensor, 1);
-	sensor->dir = g_strdup(dir);
-	sensor->basename = g_strdup(basename);
+	sensor->id_name = g_strdup(id_name);
 
-	if (dir)
-		sensor->path = g_strdup_printf("%s/%s", dir, basename);
+	if (sensor_path)
+		sensor->path = g_strdup(sensor_path);
 	else
-		sensor->path = g_strdup(basename);
+		sensor->path = g_strdup(id_name);
 	if (!default_label)
 		{
-		r = strrchr(basename, '/');
-		default_label = r ? r+1 : basename;
+		r = strrchr(id_name, '/');
+		default_label = r ? r+1 : id_name;
 		}
 	gkrellm_locale_dup_string(&sensor->name, default_label,
 				&sensor->name_locale);
@@ -208,8 +206,7 @@ strcmp_sensor_path(Sensor *s1, Sensor *s2)
 	if (s1->type != SENSOR_FAN && s2->type == SENSOR_FAN)
 		return 1;
 
-	return strcmp(s1->path, s2->path);
-//	return strcmp_basename(s1->path, s2->path);
+	return strcmp(s1->id_name, s2->id_name);
 	}
 
 static void
@@ -223,22 +220,56 @@ append_sensor_to_order_list(Sensor *sr)
 		volt_order_list = g_list_append(volt_order_list, sr);
 	}
 
+  /* Remove embedded "-i2c-" or "-isa-" from lm_sensors chip names so
+  |  there can be a chance for config name sysfs compatibility.  This function
+  |  here in sensors.c is a kludge.  Give user configs a chance to get
+  |  converted and then move this function to sysdeps/linux.c where it
+  |  belongs.
+  |  Munge names like w83627hf-isa-0290 to w83627hf-0-0290
+  |                or w83627hf-i2c-0-0290 to w83627hf-0-0290
+  |  lm_sensor i2c bus address may not be 4 digits, eg: w83782d-i2c-0-2d
+  |  and for that we want: w83782d-0-002d
+  */
+void
+gkrellm_sensors_linux_name_fix(gchar *id_name)
+	{
+#if defined(__linux__)
+	gchar	*s;
+	gint	len, bus = 0;
+	guint	addr = 0;
+
+	len = strlen(id_name) + 1;
+	if ((s = strstr(id_name, "-i2c-")) != NULL)
+		{
+		sscanf(s + 5, "%d-%x", &bus, &addr);
+		snprintf(s, len - (s - id_name), "-%d-%04x", bus, addr);
+		}
+	else if ((s = strstr(id_name, "-isa-")) != NULL)
+		{
+		*(s + 1) = '0';
+		memmove(s + 2, s + 4, strlen(s + 4) + 1);
+		}
+#endif
+	}
+
+
   /* This is called as sensors are read from the config and I will want to
   |  re-order the sensors_list to reflect the config order. Re-ordering is
   |  done by appending found sensors to type specific lists and later the
   |  sensors_list will be rebuilt from the ordered type lists.  If the
-  |  basename is found in the sensor_list, assign the label to it.
+  |  id_name is found in the sensor_list, assign the label to it.
   */
 static Sensor *
-map_sensor_label(gchar *label, gchar *basename)
+map_sensor_label(gchar *label, gchar *name)
 	{
 	GList		*list;
 	Sensor		*sr;
 
+	gkrellm_sensors_linux_name_fix(name);		/* XXX temporary, remove me */
 	for (list = sensor_list; list; list = list->next)
 		{
 		sr = (Sensor *) list->data;
-		if (!sr->has_config && !strcmp(sr->basename, basename))
+		if (!sr->has_config && !strcmp(sr->id_name, name))
 			{
 			gkrellm_locale_dup_string(&sr->name, label, &sr->name_locale);
 			append_sensor_to_order_list(sr);
@@ -341,18 +372,19 @@ gkrellm_sensor_draw_temperature_decal(GkrellmPanel *p, GkrellmDecal *d,
 	gkrellm_draw_decal_text(p, d, buf, value /* draw when changes */);
 	}
 
-Sensor *
-lookup_sensor_from_basename(gchar *basename)
+static Sensor *
+lookup_sensor_from_id_name(gchar *name)
 	{
 	GList	*list;
 	Sensor	*s;
 
-	if (!basename)
+	if (!name)
 		return NULL;
+	gkrellm_sensors_linux_name_fix(name);		/* XXX temporary, remove me */
 	for (list = sensor_list; list; list = list->next)
 		{
 		s = (Sensor *) list->data;
-		if (!strcmp(s->basename, basename))
+		if (!strcmp(s->id_name, name))
 			return s;
 		}
 	return NULL;
@@ -368,7 +400,7 @@ lookup_vref(Sensor *sr, gchar *name)
 	Sensor	*sv;
 	gchar	*s, buf[128];
 
-	snprintf(buf, 96, "%s", sr->basename);
+	snprintf(buf, 96, "%s", sr->id_name);
 	s = strrchr(buf, '/');
 	if (s)
 		++s;
@@ -379,7 +411,7 @@ lookup_vref(Sensor *sr, gchar *name)
 		{
 		sv = (Sensor *) list->data;
 		if (   sv->type == SENSOR_VOLTAGE
-			&& !strcmp(sv->basename, buf)
+			&& !strcmp(sv->id_name, buf)
 		   )
 			return sv;
 		}
@@ -476,8 +508,8 @@ sensor_read_temperature(Sensor *sensor, gfloat *temp, gchar *units)
 	if (units)
 		*units = units_fahrenheit ? 'F':'C';
 	if ((_GK.debug_level & DEBUG_SENSORS) && sensor)
-		printf("sensor_read_temperature: %s(%d) t=%f\n",
-					sensor->name_locale, found_temp, sensor->value);
+		printf("sensor_temp: %s %s t=%.2f\n",
+					sensor->name_locale, sensor->path, sensor->value);
 	if (found_temp && sensor)
 		gkrellm_check_alert(sensor->alert, sensor->value);
 	return found_temp;
@@ -512,8 +544,8 @@ sensor_read_fan(Sensor *sensor, gfloat *fan)
 	if (fan)
 		*fan = f;
 	if ((_GK.debug_level & DEBUG_SENSORS) && sensor)
-		printf("sensor_read_fan: %s(%d) rpm=%f\n",
-					sensor->name_locale, found_fan, sensor->value);
+		printf("sensor_fan: %s %s rpm=%.0f\n",
+					sensor->name_locale, sensor->path, sensor->value);
 	if (found_fan && sensor)
 		gkrellm_check_alert(sensor->alert, sensor->value);
 	return found_fan;
@@ -552,8 +584,8 @@ sensor_read_voltage(Sensor *sensor, gfloat *voltage)
 	if (voltage)
 		*voltage = v;
 	if ((_GK.debug_level & DEBUG_SENSORS) && sensor)
-		printf("sensor_read_voltage: %s(%d) v=%f\n",
-				sensor->name_locale, found_voltage, sensor->value);
+		printf("sensor_voltage: %s %s v=%.2f\n",
+				sensor->name_locale, sensor->path, sensor->value);
 	if (found_voltage && sensor)
 		gkrellm_check_alert(sensor->alert, sensor->value);
 	return found_voltage;
@@ -1444,7 +1476,7 @@ save_sensors_config(FILE *f_not_used)
 		s = (Sensor *) list->data;
 		if (s->name && *(s->name))
 			{
-			snprintf(quoted_name, sizeof(quoted_name), "\"%s\"", s->basename);
+			snprintf(quoted_name, sizeof(quoted_name), "\"%s\"", s->id_name);
 			fprintf(f, "%s \"%s\" %s %.0f %.0f %d %d\n",
 				SENSOR_CONFIG_KEYWORD,
 				s->name, quoted_name,
@@ -1461,7 +1493,7 @@ save_sensors_config(FILE *f_not_used)
 		s = (Sensor *) list->data;
 		if (s->vref)
 			fprintf(f, "%s vref \"%s\" \"%s\"\n", SENSOR_CONFIG_KEYWORD,
-					s->basename, s->vref->basename);
+					s->id_name, s->vref->id_name);
 		}
 	fprintf(f, "%s units_fahrenheit %d\n", SENSOR_CONFIG_KEYWORD,
 				units_fahrenheit);
@@ -1475,7 +1507,7 @@ load_sensors_config(gchar *arg)
 	{
 	Sensor		*s;
 	gchar		config[32], item[CFG_BUFSIZE], item1[CFG_BUFSIZE];
-	gchar		name[64], basename[CFG_BUFSIZE];
+	gchar		label[64], id_name[CFG_BUFSIZE];
 	gint		n;
 	gfloat		f	= 1.0,
 				o	= 0.0;
@@ -1498,15 +1530,15 @@ load_sensors_config(gchar *arg)
 		sscanf(item, "%f", &gkrellm_float_factor);
 	else if (!strcmp(config, "vref"))
 		{
-		if (   sscanf(item, "\"%63[^\"]\" \"%64[^\"]\"", name, item1) == 2
-			&& (s = lookup_sensor_from_basename(name)) != NULL
+		if (   sscanf(item, "\"%63[^\"]\" \"%64[^\"]\"", id_name, item1) == 2
+			&& (s = lookup_sensor_from_id_name(id_name)) != NULL
 		   )
-			s->vref = lookup_sensor_from_basename(item1);
+			s->vref = lookup_sensor_from_id_name(item1);
 		}
 	else if (!strcmp(config, GKRELLM_ALERTCONFIG_KEYWORD))
 		{
-		if (   sscanf(item, "\"%63[^\"]\" %[^\n]", name, item1) == 2
-			&& (s = lookup_sensor_from_basename(name)) != NULL
+		if (   sscanf(item, "\"%63[^\"]\" %[^\n]", id_name, item1) == 2
+			&& (s = lookup_sensor_from_id_name(id_name)) != NULL
 		   )
 			{
 			/* Since config files may be copied around, make sure to use the
@@ -1522,8 +1554,8 @@ load_sensors_config(gchar *arg)
 			}
 		}
 	else if (   sscanf(arg, "\"%63[^\"]\" \"%[^\"]\" %f %f %d %d",
-						name, basename, &f, &o, &e, &location) > 1
-			 && (s = map_sensor_label(name, basename)) != NULL
+						label, id_name, &f, &o, &e, &location) > 1
+			 && (s = map_sensor_label(label, id_name)) != NULL
 			)
 		{
 		s->factor = f / sensor_float_factor;
@@ -1543,17 +1575,20 @@ read_sensors_config(void)
 	FILE	*f;
 	Sensor	*sr;
 	GList	*list;
-	gchar	*config, *config_2_1_14 = NULL;
+	gchar	*config;
 	gchar	buf[CFG_BUFSIZE];
 
 	sprintf(buf, "%s/%s", GKRELLM_DIR, SENSOR_CONFIG_FILE);
 	config = gkrellm_make_config_file_name(gkrellm_homedir(), buf);
 	f = fopen(config, "r");
+	g_free(config);
+
 	if (!f)
 		{
 		sprintf(buf, "%s/%s", GKRELLM_DIR, SENSOR_2_1_14_CONFIG_FILE);
-		config_2_1_14 = gkrellm_make_config_file_name(gkrellm_homedir(), buf);
-		f = fopen(config_2_1_14, "r");
+		config = gkrellm_make_config_file_name(gkrellm_homedir(), buf);
+		f = fopen(config, "r");
+		g_free(config);
 		}
 	if (f)
 		{
@@ -1561,11 +1596,7 @@ read_sensors_config(void)
 		while (fgets(buf, sizeof(buf), f))
 			load_sensors_config(buf + strlen(SENSOR_CONFIG_KEYWORD) + 1);
 		fclose(f);
-//		if (config_2_1_14)
-//			rename(config_2_1_14, config);
 		}
-	g_free(config);
-	g_free(config_2_1_14);
 
 	/* In case not all sensors are in sensor_config (user edited?)
 	*/
@@ -1616,7 +1647,7 @@ set_tree_store_model_data(GtkTreeStore *tree, GtkTreeIter *iter, Sensor *s)
 	if (!s)
 		return;
 	gtk_tree_store_set(tree, iter,
-			NAME_COLUMN, s->basename ? s->basename : "??",
+			NAME_COLUMN, s->id_name ? s->id_name : "??",
 			ENABLE_COLUMN, s->enabled,
 			LABEL_COLUMN, s->name ? s->name : "??",
 			SENSOR_COLUMN, s,
