@@ -60,32 +60,42 @@ gkrellm_sys_disk_order_from_name(gchar *name)
 void
 gkrellm_sys_disk_read_data(void)
 {
-   struct disk d, *p;
-   gint	i;
-   char buf[20];
-   
+   struct disk	d, *p;
+   gint			i;
+   char			buf[20];
+   guint64		rbytes, wbytes;
 
    if (kvmd == NULL) return;
    if (n_disks <= 0) return;		/* computed by register_disks() */
    if (nl_disk[0].n_type == 0) return;	/* ditto. */
 
-   for (i = 0, p = dkdisks; i < n_disks; p = d.dk_link.tqe_next, ++i) {
-      if (kvm_read(kvmd, (u_long)p, &d, sizeof(d)) == sizeof(d)) {
-	   if ( kvm_read(kvmd, (u_long)d.dk_name, buf, sizeof(buf)) != sizeof(buf))
-	   /* fallback to default name if kvm_read failed */
-	      sprintf(buf, "%s%c", _("Disk"), 'A' + i);
+   for (i = 0, p = dkdisks; i < n_disks; p = d.dk_link.tqe_next, ++i)
+	{
+	if (kvm_read(kvmd, (u_long)p, &d, sizeof(d)) == sizeof(d))
+		{
+		if (kvm_read(kvmd, (u_long)d.dk_name, buf, sizeof(buf)) != sizeof(buf))
+			/* fallback to default name if kvm_read failed */
+			sprintf(buf, "%s%c", _("Disk"), 'A' + i);
 	 
-	 /* It seems impossible to get the read and write transfers
-	  * separately. Its just a matter of choice to put the total in
-	  * the rblk member but I like the blue color so much.
-	  *
-	  * If someone as an idea for the wblk value... It though of the
-	  * d.xfer value (number of transfers) but there a scaling problem:
-	  * d.xfer is usually much more smaller thant d.dk_bytes... */
+		/* It seems impossible to get the read and write transfers
+		 * separately. Its just a matter of choice to put the total in
+		 * the rbytes member but I like the blue color so much.
+		*/
 
-	 gkrellm_disk_assign_data_by_name(buf, d.dk_bytes, 0);
-      }
-   }
+		/* Separate read/write stats were implemented in NetBSD 1.6K.
+		*/
+
+#if __NetBSD_Version__ >= 106110000
+		rbytes = d.dk_rbytes;
+		wbytes = d.dk_wbytes;
+#else
+		rbytes = d.dk_bytes;
+		wbytes = 0;
+#endif
+
+		gkrellm_disk_assign_data_by_name(buf, rbytes, wbytes);
+		}
+	}
 }
 
 gboolean
@@ -161,7 +171,7 @@ gkrellm_sys_inet_read_tcp_data(void)
 		sizeof(struct inpcbtable)) != sizeof(struct inpcbtable))
       return;
 
-   next = table.inpt_queue.cqh_first;
+   next = (struct inpcb *)table.inpt_queue.cqh_first;
    while(next != NULL) {
       
       if (kvm_read(kvmd, (u_long)next,
@@ -178,7 +188,7 @@ gkrellm_sys_inet_read_tcp_data(void)
 	    gkrellm_inet_log_tcp_port_data(&tcp);
       }
 
-      next = inpcb.inp_queue.cqe_next;
+      next = (struct inpcb *)inpcb.inp_queue.cqe_next;
    }
 }
 
