@@ -1152,7 +1152,10 @@ gkrellm_sys_battery_read_data(void)
 			on_line = acpi_info[ACPI_ACLINE];
 			charging = (acpi_info[ACPI_BATT_STATE] == ACPI_BATT_STAT_CHARGING);
 			percent = acpi_info[ACPI_BATT_LIFE];
-			time_left = acpi_info[ACPI_BATT_TIME];
+			if (acpi_info[ACPI_BATT_TIME] == 0 && percent > 0)
+				time_left = -1;
+			else
+				time_left = acpi_info[ACPI_BATT_TIME];
 			gkrellm_battery_assign_data(
 				GKRELLM_BATTERY_COMPOSITE_ID, available,
 				on_line, charging, percent, time_left);
@@ -1172,7 +1175,7 @@ gkrellm_sys_battery_read_data(void)
 	charging = (info.ai_batt_stat == L_CHARGING) ? TRUE : FALSE;
 	percent = info.ai_batt_life;
 #if defined(APM_GETCAPABILITIES)
-	if (info.ai_batt_time == -1)
+	if (info.ai_batt_time == -1 || (info.ai_batt_time == 0 && percent > 0))
 		time_left = -1;
 	else
 		time_left = info.ai_batt_time / 60;
@@ -1203,9 +1206,8 @@ gkrellm_sys_battery_read_data(void)
 			charging = (aps.ap_batt_stat == L_CHARGING) ?
 				TRUE : FALSE;
 			percent = aps.ap_batt_life;
-			if (aps.ap_batt_time == 0 &&
-			    (aps.ap_batt_stat == L_UNKNOWN ||
-			     aps.ap_batt_stat == L_CHARGING))
+			if (aps.ap_batt_time == -1 ||
+			    (aps.ap_batt_time == 0 && percent > 0))
 				time_left = -1;
 			else
 				time_left = aps.ap_batt_time / 60;
@@ -1398,7 +1400,7 @@ gkrellm_sys_sensors_get_voltage(gchar *path, gint id,
 
 struct freebsd_sensor {
 	gint type;
-	gchar *basename;
+	gchar *id_name;
 	gint id;
 	gint iodev;
 	gint inter;
@@ -1412,7 +1414,7 @@ static GList	*freebsd_sensor_list;
 gboolean
 gkrellm_sys_sensors_init(void)
 	{
-	gchar		temp_file[256], label[8];
+	gchar		mib_name[256], label[8];
 	gint		interface, id;
 	int		oid_acpi_temp[CTL_MAXNAME + 2];
 	size_t		oid_acpi_temp_len = sizeof(oid_acpi_temp);
@@ -1422,18 +1424,18 @@ gkrellm_sys_sensors_init(void)
 
 	for (id = 0;;)
 	{
-		snprintf(temp_file, sizeof(temp_file),
+		snprintf(mib_name, sizeof(mib_name),
 			 "hw.acpi.thermal.tz%d.temperature", id);
-		if (gk_sysctlnametomib(temp_file, oid_acpi_temp,
+		if (gk_sysctlnametomib(mib_name, oid_acpi_temp,
 				       &oid_acpi_temp_len) < 0)
 			break;
 		interface = INTERFACE_ACPI;
-		if (!gkrellm_sys_sensors_get_temperature(temp_file, 0, 0,
+		if (!gkrellm_sys_sensors_get_temperature(mib_name, 0, 0,
 							 interface, NULL))
 			continue;
 		snprintf(label, sizeof(label), "tz%d", id);
 		gkrellm_sensors_add_sensor(SENSOR_TEMPERATURE, NULL,
-					   temp_file, 0, 0,
+					   mib_name, 0, 0,
 					   interface, 1.0, 0.0, NULL, label);
 		found_acpi_sensors = TRUE;
 	}
@@ -1443,8 +1445,8 @@ gkrellm_sys_sensors_init(void)
 		for (list = freebsd_sensor_list; list; list = list->next)
 			{
 			sensor = (struct freebsd_sensor *)list->data;
-			gkrellm_sensors_add_sensor(sensor->type, SENSORS_DIR,
-					sensor->basename, sensor->id,
+			gkrellm_sensors_add_sensor(sensor->type, NULL,
+					sensor->id_name, sensor->id,
 					sensor->iodev, sensor->inter,
 					sensor->factor, sensor->offset,
 					NULL, sensor->default_label);
@@ -1456,7 +1458,7 @@ gkrellm_sys_sensors_init(void)
 	}
 
 static gboolean
-sensors_add_sensor(gint type, gchar *basename, gint id, gint iodev, gint inter,
+sensors_add_sensor(gint type, gchar *id_name, gint id, gint iodev, gint inter,
 		   gfloat factor, gfloat offset, gchar *default_label)
 {
 	struct freebsd_sensor *sensor;
@@ -1464,7 +1466,7 @@ sensors_add_sensor(gint type, gchar *basename, gint id, gint iodev, gint inter,
 	if ((sensor = g_new0(struct freebsd_sensor, 1)) == NULL)
 		return FALSE;
 	sensor->type = type;
-	sensor->basename = g_strdup(basename);
+	sensor->id_name = g_strdup(id_name);
 	sensor->id = id;
 	sensor->iodev = iodev;
 	sensor->inter = inter;
@@ -1472,7 +1474,7 @@ sensors_add_sensor(gint type, gchar *basename, gint id, gint iodev, gint inter,
 	sensor->offset = offset;
 	sensor->default_label = default_label ? g_strdup(default_label) : NULL;
 	if (g_list_append(freebsd_sensor_list, sensor) == NULL) {
-		g_free(sensor->basename);
+		g_free(sensor->id_name);
 		if (sensor->default_label)
 			g_free(sensor->default_label);
 		g_free(sensor);
@@ -1489,7 +1491,7 @@ scan_for_sensors(void)
 	DIR		*dir;
 	struct dirent	*dentry;
 #endif
-	gchar		temp_file[256], base_name[8];
+	gchar		temp_file[256], id_name[8];
 	gint		iodev = -1, interface = -1, id;
 	gint		fandiv[3];
 	u_char		byte;
@@ -1508,7 +1510,7 @@ scan_for_sensors(void)
 						chip_dir, dentry->d_name);
 			if ((iodev = open(temp_file, O_RDWR)) == -1)
 				continue;
-			sprintf(base_name, "%s%3s", "temp", dentry->d_name + 3);
+			sprintf(id_name, "%s%3s", "temp", dentry->d_name + 3);
 			interface = INTERFACE_SMB;
 			if (!gkrellm_sys_sensors_get_temperature(NULL, 0, iodev,
 					interface, NULL))
@@ -1516,7 +1518,7 @@ scan_for_sensors(void)
 				close(iodev);
 				continue;
 				}
-			sensors_add_sensor(SENSOR_TEMPERATURE, base_name, 0,
+			sensors_add_sensor(SENSOR_TEMPERATURE, id_name, 0,
 					iodev, interface, 1.0, 0.0, NULL);
 			found_sensors = TRUE;
 			break;
@@ -1553,8 +1555,8 @@ scan_for_sensors(void)
 				if (!gkrellm_sys_sensors_get_fan(NULL, id, iodev,
 						interface, NULL))
 					continue;
-				sprintf(base_name, "%s%d", "fan", id);
-				sensors_add_sensor(SENSOR_FAN, base_name, id,
+				sprintf(id_name, "%s%d", "fan", id);
+				sensors_add_sensor(SENSOR_FAN, id_name, id,
 						iodev, interface,
 						1.0 / (gfloat) fandiv[id], 0.0,
 						NULL);
@@ -1565,8 +1567,8 @@ scan_for_sensors(void)
 			if (!gkrellm_sys_sensors_get_voltage(NULL, id, iodev,
 					interface, NULL))
 				continue;
-			sprintf(base_name, "%s%d", "in", id);
-			sensors_add_sensor(SENSOR_VOLTAGE, base_name, id,
+			sprintf(id_name, "%s%d", "in", id);
+			sensors_add_sensor(SENSOR_VOLTAGE, id_name, id,
 					iodev, interface,
 					voltdefault0[id].factor, 0.0,
 					voltdefault0[id].name);
