@@ -1824,8 +1824,14 @@ gkrellm_sys_uptime_init(void)
 /* Sensor monitor interface */
 /* ------- Linux ------------------------------------------------------- */
 
-#define	SENSORS_DIR	"/proc/sys/dev/sensors"
-#define SYSFS_I2C_DIR	"/sys/bus/i2c/devices"
+#define	THERMAL_ZONE_DIR	"/proc/acpi/thermal_zone"
+#define	THERMAL_DIR			"/proc/acpi/thermal"
+#define	SENSORS_DIR			"/proc/sys/dev/sensors"
+#define SYSFS_I2C_DIR		"/sys/bus/i2c/devices"
+
+#define	LM_SENSOR				0
+#define	THERMAL_SENSOR			1
+#define	THERMAL_ZONE_SENSOR		2
 
 typedef struct
 	{
@@ -1952,100 +1958,54 @@ static VoltDefault	voltdefault9[] =
 	{ "+3.3V",	1.0,    0, 		NULL }
 	};
 
-static gboolean
-sysfs_get_sensor(gchar *device_name, gint id, gint type, gfloat *val)
-	{
-	gchar		*path, *p, *name = NULL;
-	FILE		*f;
-	gfloat		V = 0.0;
-	gint		t, n;
-	gboolean	ret = FALSE;
-
-	/* get file name back */
-	path = g_strdup(device_name);
-	if (!path)
-		goto out;
-	p = strrchr(path, '/');
-	if (!p)
-		goto free_path;
-	*p = '\0';
-	p = strrchr(path, '/');
-	if (!p)
-		goto free_path;
-	*p = '\0';
-
-	switch (type)
-		{
-		case SENSOR_VOLTAGE:
-			name = g_strdup_printf("%s/%s%d", path, "in_input", id); 
-			break;
-		case SENSOR_FAN:
-			name = g_strdup_printf("%s/%s%d", path, "fan_input", id); 
-			break;
-		case SENSOR_TEMPERATURE:
-			name = g_strdup_printf("%s/%s%d", path, "temp_input", id); 
-			break;
-		}
-	if (!name)
-		goto free_path;
-
-	if ((f = fopen(name, "r")) == NULL)
-		goto free_name;
-	n = fscanf(f, "%d", &t);
-	fclose(f);
-
-	if (n < 1)
-		goto free_name;
-
-	switch (type)
-		{
-		case SENSOR_VOLTAGE:
-			V = (gfloat) t / 1000.0;
-			break;
-		case SENSOR_TEMPERATURE:
-			V = (gfloat) t / 100.0;
-			break;
-		case SENSOR_FAN:
-			V = (gfloat) t;
-			break;
-		}
-
-	if (val)
-		*val = V;
-	ret = TRUE;
-
-free_name:
-	g_free(name);
-free_path:
-	g_free(path);
-out:
-	return ret;
-}
 
 gboolean
-gkrellm_sys_sensors_get_temperature(gchar *device_name, gint id,
+gkrellm_sys_sensors_get_temperature(gchar *sensor_path, gint id,
 		gint iodev, gint interface, gfloat *temp)
 	{
-	FILE	*f;
-	gchar	buf[64];
-	gint	n;
-	gfloat	T, t[5];
+	FILE		*f;
+	gchar		buf[64], units[32];
+	gint		n;
+	gfloat		T, t[5];
+	gboolean	result = FALSE;
 
-	if (have_sysfs_sensors)
-		return sysfs_get_sensor(device_name, id, SENSOR_TEMPERATURE, temp);
+	if (interface == THERMAL_SENSOR || interface == THERMAL_ZONE_SENSOR)
+		{
+		f = fopen(sensor_path, "r");
+		if (f)
+			{
+			while (fgets(buf, sizeof(buf), f) != NULL)
+				{
+				if (need_locale_fix)
+					locale_fix(buf);
+				if ((n = sscanf(buf, "temperature: %f %31s", &T, units)) > 0)
+					{
+					if (n == 2 && !strcmp(units, "dK"))
+						T = T / 10.0 - 273.0;
+					*temp = T;
+					result = TRUE;
+					}
+				}
+			fclose(f);
+			}
+		return result;
+		}
 	
-	if ((f = fopen(device_name, "r")) == NULL)
+	if ((f = fopen(sensor_path, "r")) == NULL)
 		return FALSE;
 	fgets(buf, sizeof(buf), f);
 	fclose(f);
 
-	if (need_locale_fix)
+	if (!have_sysfs_sensors && need_locale_fix)
 		locale_fix(buf);
 	n = sscanf(buf, "%f %f %f %f %f", &t[0], &t[1], &t[2], &t[3], &t[4]);
 	if (n < 1)
 		return FALSE;
 	T = t[n - 1];
-	if (T > 254.0)		/* Bogus read from BIOS if CHAR_MAX */
+
+	if (have_sysfs_sensors)
+		T /= 100.0;
+	else if (T > 254.0)		/* Bogus read from BIOS if CHAR_MAX */
 		return FALSE;
 
 	if (temp)
@@ -2054,7 +2014,7 @@ gkrellm_sys_sensors_get_temperature(gchar *device_name, gint id,
 	}
 
 gboolean
-gkrellm_sys_sensors_get_fan(gchar *device_name, gint id,
+gkrellm_sys_sensors_get_fan(gchar *sensor_path, gint id,
 		gint iodev, gint interface, gfloat *fan)
 	{
 	FILE	*f;
@@ -2062,15 +2022,12 @@ gkrellm_sys_sensors_get_fan(gchar *device_name, gint id,
 	gint	n;
 	gfloat	t[4];
 
-	if (have_sysfs_sensors)
-		return sysfs_get_sensor(device_name, id, SENSOR_FAN, fan);
-
-	if ((f = fopen(device_name, "r")) == NULL)
+	if ((f = fopen(sensor_path, "r")) == NULL)
 		return FALSE;
 	fgets(buf, sizeof(buf), f);
 	fclose(f);
 
-	if (need_locale_fix)
+	if (!have_sysfs_sensors && need_locale_fix)
 		locale_fix(buf);
 	n = sscanf(buf, "%f %f %f %f", &t[0], &t[1], &t[2], &t[3]);
 	if (n < 1)
@@ -2082,7 +2039,7 @@ gkrellm_sys_sensors_get_fan(gchar *device_name, gint id,
 	}
 
 gboolean
-gkrellm_sys_sensors_get_voltage(gchar *device_name, gint id,
+gkrellm_sys_sensors_get_voltage(gchar *sensor_path, gint id,
 		gint iodev, gint interface, gfloat *volt)
 	{
 	FILE	*f;
@@ -2090,21 +2047,21 @@ gkrellm_sys_sensors_get_voltage(gchar *device_name, gint id,
 	gfloat	V, t[3];
 	gint	n;
 
-	if (have_sysfs_sensors)
-		return sysfs_get_sensor(device_name, id, SENSOR_VOLTAGE, volt);
-
-	if ((f = fopen(device_name, "r")) == NULL)
+	if ((f = fopen(sensor_path, "r")) == NULL)
 		return FALSE;
 	fgets(buf, sizeof(buf), f);
 	fclose(f);
 
-	if (need_locale_fix)
+	if (!have_sysfs_sensors && need_locale_fix)
 		locale_fix(buf);
 	n = sscanf(buf, "%f %f %f", &t[0], &t[1], &t[2]);
 	if (n < 1)
 		return FALSE;
 	V = t[n - 1];
-	if (V > 254.0)
+
+	if (have_sysfs_sensors)
+		V /= 1000.0;
+	else if (V > 254.0)		/* Bogus read from BIOS if CHAR_MAX */
 		return FALSE;
 
 	if (volt)
@@ -2179,32 +2136,24 @@ sysfs_get_chip_name(gchar *dir)
 	gchar	*name, buf[256], *p, *chip;
 	FILE 	*f;
 
-	name = g_strdup_printf("%s/%s/%s", SYSFS_I2C_DIR, dir, "name");
-	if (!name)
-		return NULL;
+	name = g_strdup_printf("%s/%s", dir, "name");
 	f = fopen(name, "r");
 	g_free(name);
 	if (!f)
 		return NULL;
 
-	if (fgets(buf, sizeof(buf), f) == NULL)
-		{
-		fclose(f);
-		return NULL;
-		}
+	buf[0] = '\0';
+	fscanf(f, "%255[^\n]", buf);
 	fclose(f);
-	
-	if (buf[strlen(buf) - 1] == '\n')
-		buf[strlen(buf) - 1] = '\0';
-
-	p = strchr(buf, ' ');
-	if (!p)
+	if (buf[0] == '\0')
 		return NULL;
 
-	*p++ = '\0';
-	/* FIXME anybody has better idea how to detect sensor chip? */
-	if (strcmp(p, "chip") && strcmp(p, "subclient"))
-		return NULL;
+	if ((p = strchr(buf, ' ')) != NULL)		/* Remove when 2.6.0 is out */
+		{									/* "w83627hf chip" -> "w83627hf" */
+		*p++ = '\0';
+		if (strcmp(p, "chip") && strcmp(p, "subclient"))
+			return NULL;
+		}
 
 	chip = g_strdup(buf);
 	for (p = chip; *p; p++)
@@ -2212,67 +2161,54 @@ sysfs_get_chip_name(gchar *dir)
 	return chip;
 	}
 
-static gboolean
+static void
 sysfs_sensors_init(void)
 	{
-	DIR				*dir, *chip_dir;
-	struct dirent	*dentry, *chip_dentry;
+	GDir			*dir, *chip_dir;
 	VoltDefault		*voltdefault;
-	gint			id = 0, bus;
-	guint			addr;
-	gint			type, voltdefaultsize, n_volt_sensors;
+	gint			id = 0;
+	gint			type, voltdefaultsize;
 	gfloat			factor, offset;
-	gchar			*name, *default_label, *vref, *compat,
-					*base_name,  *chip_name;
-	gchar			path[256];
+	gchar			*name, *bus_name, *default_label, *vref,
+					*id_name,  *chip_name, *s, *sensor_path;
+	gchar			path[256], buf[256];
 
 	if (!have_sysfs)
-		return TRUE;
+		return;
 
-	if ((dir = opendir(SYSFS_I2C_DIR)) == NULL)
-		return TRUE;
-	n_volt_sensors = 0;
-	while ((dentry = readdir(dir)) != NULL)
+	if ((dir = g_dir_open(SYSFS_I2C_DIR, 0, NULL)) == NULL)
+		return;
+	while ((bus_name = (gchar *) g_dir_read_name(dir)) != NULL)
 		{
-		if (dentry->d_name[0] == '.' || dentry->d_ino <= 0)
+		snprintf(path, sizeof(path), "%s/%s", SYSFS_I2C_DIR, bus_name);
+		if ((chip_dir = g_dir_open(path, 0, NULL)) == NULL)
 			continue;
-		snprintf(path, sizeof(path), "%s/%s", SYSFS_I2C_DIR, dentry->d_name);
-		if ((chip_dir = opendir(path)) == NULL)
-			continue;
-		if ((chip_name = sysfs_get_chip_name(dentry->d_name)) == NULL)
+		if ((chip_name = sysfs_get_chip_name(path)) == NULL)
 			{
-			closedir(chip_dir);
+			g_dir_close(chip_dir);
 			continue;
 			}
 		have_sysfs_sensors = TRUE;
+		if (_GK.debug_level & DEBUG_SENSORS)
+				printf("sysfs sensors dir: %s\n", path);
+
 		get_volt_default(chip_name, &voltdefault, &voltdefaultsize);
-		while ((chip_dentry = readdir(chip_dir)) != NULL)
+		while ((name = (gchar *) g_dir_read_name(chip_dir)) != NULL)
 			{
-			name = chip_dentry->d_name;
-			if (   !strncmp(name, "temp_input", 10)
-				&& isdigit(name[10]) && !name[11]
+			if (   (s = strstr(name, "_input")) == NULL
+				|| s - name > 4 || !isdigit(*(s + 6))
 			   )
-				{
+				continue;
+			strncpy(buf, name, s - name);
+			strcpy(&buf[s - name], s + 6);
+			id = atoi(s + 6);
+
+			if (!strncmp(buf, "temp", 4))
 				type = SENSOR_TEMPERATURE;
-				id = name[10] - '0';
-				compat = "temp";
-				}
-			else if (   !strncmp(name, "fan_input", 9)
-					 && isdigit(name[9]) && !name[10]
-				    )
-				{
+			else if (!strncmp(buf, "fan", 3))
 				type = SENSOR_FAN;
-				id = name[9] - '0';
-				compat = "fan";
-				}
-			else if (   !strncmp(name, "in_input", 8)
-					 && isdigit(name[8]) && !name[9]
-					)
-				{
+			else if (!strncmp(buf, "in", 2))
 				type = SENSOR_VOLTAGE;
-				id = name[8] - '0';
-				compat = "in";
-				}
 			else
 				continue;
 
@@ -2290,40 +2226,51 @@ sysfs_sensors_init(void)
 					vref = voltdefault[id].vref;
 					}
 				else
-					default_label =  compat;
+					default_label =  buf;
 				}
-			/* the following is kludge to make config compatible with /proc
-			*/
-			sscanf(dentry->d_name, "%d-%x", &bus, &addr);
-			base_name = g_strdup_printf("%s-i2c-%d-%x/%s%d",
-						chip_name, bus, addr,
-						compat, id);
-			gkrellm_sensors_add_sensor(type, path, base_name,
+			id_name = g_strdup_printf("%s-%s/%s", chip_name, bus_name, buf);
+			sensor_path = g_strdup_printf("%s/%s", path, name);
+			gkrellm_sensors_add_sensor(type, sensor_path, id_name,
 						id, 0, 0,
 						factor, offset, vref, default_label);
-			g_free(base_name);
-
 			if (_GK.debug_level & DEBUG_SENSORS)
-				printf("sys_sensors_init: %s/%s %d\n", path, name, type);
+				printf("%s %s %d %d\n",
+							sensor_path, id_name, id, type);
+			g_free(id_name);
+			g_free(sensor_path);
 			}
 		g_free(chip_name);
-		closedir(chip_dir);
+		g_dir_close(chip_dir);
 		}
-	closedir(dir);
-	return TRUE;
+	g_dir_close(dir);
 	}
 
+  /* Eventually, move this function from sensors.c to here where
+  |  it belongs.
+  */
+extern void		gkrellm_sensors_linux_name_fix(gchar *chip_name);
+
+  /* lm_sensors can have "-isa-" or "-i2c-" embedded in /proc chip names so
+  |  they are of form w83627hf-isa-0290.  Sensors from sysfs are derived from
+  |  a bus directory "0-0290" and "name" file with content like "w83627hf"
+  |  which leads to chip names like "w83627hf-0-0290" without the i2c or
+  |  isa.  To have a chance at config compatibility between the two,
+  |  remove the "i2c" and replace the "isa" with "0" in lm_sensors name
+  |  when generating the id_name.  I don't want to do any munging on the
+  |  sysfs names because I can't guess if the lm_sensors names had "i2c" or
+  |  "isa", and besides, probably sysfs will eventually be more common
+  |  so I'll just make its names the standard now (gkrellm 2.1.20).
+  */
 gboolean
 gkrellm_sys_sensors_init(void)
 	{
-	DIR				*dir, *chip_dir;
-	struct dirent	*dentry, *chip_dentry;
+	GDir			*dir, *chip_dir;
 	VoltDefault		*voltdefault;
 	gint			id = 0;
-	gint			type, voltdefaultsize, n_volt_sensors;
+	gint			type, voltdefaultsize;
 	gfloat			factor, offset;
-	gchar			*name, *default_label, *vref;
-	gchar			path[256], base_name[128];
+	gchar			*name, *chip_name, *fixed_chip_name, *path, *default_label;
+	gchar			*vref, *sensor_path, *sensor_name, id_name[128];
 	struct lconv	*lc;
 
 	lc = localeconv();
@@ -2331,40 +2278,85 @@ gkrellm_sys_sensors_init(void)
 	if (locale_decimal_point != '.')
 		need_locale_fix = TRUE;
 
-	if ((dir = opendir(SENSORS_DIR)) == NULL)
+	if ((dir = g_dir_open(THERMAL_ZONE_DIR, 0, NULL)) != NULL)
+		{
+		while ((name = (gchar *) g_dir_read_name(dir)) != NULL)
+			{
+			path = g_build_filename(THERMAL_ZONE_DIR, name,
+						"temperature", NULL);
+			if (g_file_test(path, G_FILE_TEST_IS_REGULAR))
+				{
+				snprintf(id_name, sizeof(id_name), "thermal_zone/%s", name);
+				gkrellm_sensors_add_sensor(SENSOR_TEMPERATURE,
+							path, id_name,
+							id, 0, THERMAL_ZONE_SENSOR,
+							1.0, 0.0, NULL, name);
+				}
+			g_free(path);
+			}
+		g_dir_close(dir);
+		}
+
+	if ((dir = g_dir_open(THERMAL_DIR, 0, NULL)) != NULL)
+		{
+		while ((name = (gchar *) g_dir_read_name(dir)) != NULL)
+			{
+			path = g_build_filename(THERMAL_DIR, name, "status", NULL);
+			if (g_file_test(path, G_FILE_TEST_IS_REGULAR))
+				{
+				snprintf(id_name, sizeof(id_name), "thermal/%s", name);
+				gkrellm_sensors_add_sensor(SENSOR_TEMPERATURE,
+							path, id_name,
+							id, 0, THERMAL_SENSOR,
+							1.0, 0.0, NULL, name);
+				}
+			g_free(path);
+			}
+		g_dir_close(dir);
+		}
+
+	if ((dir = g_dir_open(SENSORS_DIR, 0, NULL)) == NULL)
 		{
 		sysfs_sensors_init();
 		return TRUE;
 		}
-	n_volt_sensors = 0;
-	while ((dentry = readdir(dir)) != NULL)
+	while ((chip_name = (gchar *) g_dir_read_name(dir)) != NULL)
 		{
-		if (dentry->d_name[0] == '.' || dentry->d_ino <= 0)
-			continue;
-		snprintf(path, sizeof(path), "%s/%s", SENSORS_DIR, dentry->d_name);
-		if ((chip_dir = opendir(path)) == NULL)
-			continue;
-		get_volt_default(dentry->d_name, &voltdefault, &voltdefaultsize);
-		while ((chip_dentry = readdir(chip_dir)) != NULL)
+		fixed_chip_name = g_strdup(chip_name);
+		gkrellm_sensors_linux_name_fix(fixed_chip_name);
+		
+		path = g_build_filename(SENSORS_DIR, chip_name, NULL);
+		chip_dir = g_dir_open(path, 0, NULL);
+		if (!chip_dir)
 			{
-			name = chip_dentry->d_name;
-			if (!strncmp(name, "temp", 4))
+			g_free(path);
+			continue;
+			}
+		if (_GK.debug_level & DEBUG_SENSORS)
+				printf("lm_sensors dir: %s\n", path);
+
+		get_volt_default(chip_name, &voltdefault, &voltdefaultsize);
+		while ((sensor_name = (gchar *) g_dir_read_name(chip_dir)) != NULL)
+			{
+			if (!strncmp(sensor_name, "temp", 4))
 				type = SENSOR_TEMPERATURE;
-			else if (   !strncmp(name, "fan", 3)
-					 && (!name[3] || (isdigit(name[3]) && !name[4]))
+			else if (   !strncmp(sensor_name, "fan", 3)
+					 && (  !sensor_name[3]
+						|| (isdigit(sensor_name[3]) && !sensor_name[4])
+						)
 					)
 				type = SENSOR_FAN;
-			else if (!strncmp(name, "in", 2) && isdigit(name[2]))
+			else if (!strncmp(sensor_name, "in", 2) && isdigit(sensor_name[2]))
 				{
 				type = SENSOR_VOLTAGE;
-				id = name[2] - '0';
+				id = sensor_name[2] - '0';
 				}
-			else if (!strncmp(name, "vi", 2) && isdigit(name[3]))
+			else if (!strncmp(sensor_name, "vi", 2) && isdigit(sensor_name[3]))
 				{
 				type = SENSOR_VOLTAGE;
-				id = name[3] - '0';
+				id = sensor_name[3] - '0';
 				}
-			else if (!strcmp(name, "vdd"))
+			else if (!strcmp(sensor_name, "vdd"))
 				{
 				type = SENSOR_VOLTAGE;
 				id = 0;
@@ -2386,19 +2378,24 @@ gkrellm_sys_sensors_init(void)
 					vref = voltdefault[id].vref;
 					}
 				else
-					default_label =  name;
+					default_label =  sensor_name;
 				}
-			snprintf(base_name, sizeof(base_name), "%s/%s",
-						dentry->d_name, name);
-			gkrellm_sensors_add_sensor(type, SENSORS_DIR, base_name,
+			sensor_path = g_strdup_printf("%s/%s", path, sensor_name);
+			snprintf(id_name, sizeof(id_name), "%s/%s",
+						fixed_chip_name, sensor_name);
+			gkrellm_sensors_add_sensor(type, sensor_path, id_name,
 					id, 0, 0,
 					factor, offset, vref, default_label);
 
 			if (_GK.debug_level & DEBUG_SENSORS)
-				printf("sys_sensors_init: %s/%s %d\n", path, name, type);
+				printf("%s %s %d %d\n",
+							sensor_path, id_name, id, type);
+			g_free(sensor_path);
 			}
-		closedir(chip_dir);
+		g_dir_close(chip_dir);
+		g_free(path);
+		g_free(fixed_chip_name);
 		}
-	closedir(dir);
+	g_dir_close(dir);
 	return TRUE;
 	}
