@@ -201,10 +201,10 @@ void		gkrellm_alloc_chartdata(GkrellmChart *a)
 {
     (*(callbacks->gkrellm_alloc_chartdata))(a);
 }
-//void		gkrellm_store_chartdata(GkrellmChart *a, gulong b, ...)
-//{
-//    (*(callbacks->gkrellm_store_chartdata))(a, b, ...);
-//}
+void		gkrellm_store_chartdata(GkrellmChart *a, gulong b, gulong c, gulong d)
+{
+    (*(callbacks->gkrellm_store_chartdata))(a, b, c, d);
+}
 void		gkrellm_draw_chartdata(GkrellmChart *a)
 {
     (*(callbacks->gkrellm_draw_chartdata))(a);
@@ -1299,3 +1299,48 @@ void		gkrellm_set_external_mbox_tooltip(gpointer a, gchar *b)
     (*(callbacks->gkrellm_set_external_mbox_tooltip))(a, b);
 }
 
+
+      /* Functions new for 2.1.8
+      */
+void		gkrellm_panel_label_on_top_of_decals(GkrellmPanel *p,
+					gboolean mode)
+{
+    (*(callbacks->gkrellm_panel_label_on_top_of_decals))(p, mode);
+}
+gboolean	gkrellm_alert_is_activated(GkrellmAlert *alert)
+{
+    return (*(callbacks->gkrellm_alert_is_activated))(alert);
+}
+void		gkrellm_alert_dup(GkrellmAlert **ap, GkrellmAlert *a_src)
+{
+    (*(callbacks->gkrellm_alert_dup))(ap, a_src);
+}
+void		gkrellm_alert_config_create_connect(GkrellmAlert *alert,
+					void (*func)(), gpointer data)
+{
+    (*(callbacks->gkrellm_alert_config_create_connect))(alert, func, data);
+}
+void		gkrellm_alert_command_process_connect(GkrellmAlert *alert,
+					void (*func)(), gpointer data)
+{
+    (*(callbacks->gkrellm_alert_command_process_connect))(alert, func, data);
+}
+gboolean	gkrellm_alert_decal_visible(GkrellmAlert *alert)
+{
+    return (*(callbacks->gkrellm_alert_decal_visible))(alert);
+}
+void		gkrellm_alert_set_delay(GkrellmAlert *alert, gint delay)
+{
+    (*(callbacks->gkrellm_alert_set_delay))(alert, delay);
+}
+void		gkrellm_alert_delay_config(GkrellmAlert *alert, gint step,
+					gint high, gint low)
+{
+    (*(callbacks->gkrellm_alert_delay_config))(alert, step, high, low);
+}
+void		gkrellm_gtk_alert_button(GtkWidget *box, GtkWidget **button,
+					gboolean expand, gboolean fill, gint pad,
+					gboolean pack_start, void (*cb_func)(), gpointer data)
+{
+    (*(callbacks->gkrellm_gtk_alert_button))(box, button, expand, fill, pad, pack_start, cb_func, data);
+}
