@@ -228,14 +228,10 @@ void gkrellm_sys_main_init(void)
     GetVersionEx(&info);
 
     // see if we can use the GetDiskFreeSpaceEx function
-    if (info.dwPlatformId == VER_PLATFORM_WIN32_WINDOWS && info.dwMinorVersion == 0) {
-        // The GetDiskFreeSpaceEx function is available on Windows 95 systems beginning with OEM Service Release 2 (OSR2).
-        mod = LoadLibrary("KERNEL32.DLL");
-        proc = GetProcAddress(mod, "GetDiskFreeSpaceEx");
-        if (proc != NULL) {
-            fswin95 = 1;
-        }
-        FreeLibrary(mod);
+    mod = GetModuleHandle("KERNEL32.DLL");
+    proc = GetProcAddress(mod, "GetDiskFreeSpaceExA");
+    if (proc != NULL) {
+        fswin95 = 1;
     }
 
     // we don't have local mail on Windows (yet?)
@@ -2213,7 +2209,7 @@ void win32_init_callbacks(void)
     plugin_callbacks.gkrellm_add_chartdata = gkrellm_add_chartdata;
     plugin_callbacks.gkrellm_add_default_chartdata = gkrellm_add_default_chartdata;
     plugin_callbacks.gkrellm_alloc_chartdata = gkrellm_alloc_chartdata;
-//    plugin_callbacks.gkrellm_store_chartdata = gkrellm_store_chartdata;
+    plugin_callbacks.gkrellm_store_chartdata = gkrellm_store_chartdata;
     plugin_callbacks.gkrellm_draw_chartdata = gkrellm_draw_chartdata;
     plugin_callbacks.gkrellm_monotonic_chartdata = gkrellm_monotonic_chartdata;
     plugin_callbacks.gkrellm_get_chartdata_hide = gkrellm_get_chartdata_hide;
@@ -2471,12 +2467,6 @@ void win32_init_callbacks(void)
     plugin_callbacks.gkrellm_make_data_file_name = gkrellm_make_data_file_name;
     plugin_callbacks.gkrellm_get_current_time = gkrellm_get_current_time;
     plugin_callbacks.gkrellm_125_sequence = gkrellm_125_sequence;
-
-      /* Session manager plugin helpers
-      */
-//    plugin_callbacks.gkrellm_get_sm_argc = gkrellm_get_sm_argc;
-//    plugin_callbacks.gkrellm_get_sm_argv = gkrellm_get_sm_argv;
-//    plugin_callbacks.gkrellm_get_restart_options = gkrellm_get_restart_options;
     plugin_callbacks.gkrellm_save_all = gkrellm_save_all;
 
       /* ------- Some builtin monitor public functions -------- */
@@ -2507,6 +2497,18 @@ void win32_init_callbacks(void)
     plugin_callbacks.gkrellm_get_theme_scale = gkrellm_get_theme_scale;
     plugin_callbacks.gkrellm_offset_chartdata = gkrellm_offset_chartdata;
     plugin_callbacks.gkrellm_make_scaled_decal_pixmap = gkrellm_make_scaled_decal_pixmap;
+
+    /* Functions new for 2.1.8
+    */
+	plugin_callbacks.gkrellm_panel_label_on_top_of_decals = gkrellm_panel_label_on_top_of_decals;
+	plugin_callbacks.gkrellm_alert_is_activated = gkrellm_alert_is_activated;
+	plugin_callbacks.gkrellm_alert_dup = gkrellm_alert_dup;
+	plugin_callbacks.gkrellm_alert_config_create_connect = gkrellm_alert_config_create_connect;
+	plugin_callbacks.gkrellm_alert_command_process_connect = gkrellm_alert_command_process_connect;
+	plugin_callbacks.gkrellm_alert_decal_visible = gkrellm_alert_decal_visible;
+	plugin_callbacks.gkrellm_alert_set_delay = gkrellm_alert_set_delay;
+	plugin_callbacks.gkrellm_alert_delay_config = gkrellm_alert_delay_config;
+	plugin_callbacks.gkrellm_gtk_alert_button = gkrellm_gtk_alert_button;
     
     callbacks = &plugin_callbacks;
 #endif
@@ -2683,3 +2685,4 @@ if (addr != NULL)
 addr->s_addr = htonl(val);
 return (1);
 }
+
