@@ -62,6 +62,51 @@ gkrellm_dup_string(gchar **dst, gchar *src)
 	return TRUE;
 	}
 
+static gboolean
+any(gchar c, gchar *s)
+	{
+	while (*s)
+		if (c == *s++)
+			return TRUE;
+	return FALSE;
+	}
+
+  /* Return a duplicated token from a string.  "*string" points to the source
+  |  string and is updated to point to the string remaining after the
+  |  found token.  If there is no next token, return an empty dupped string
+  |  (not a NULL pointer) and leave *string unchanged.
+  |  Unlike strtok(): args are not modified, gkrellm_token() can be used on
+  |  constant strings, delimeter identity is not lost, and it's thread safe.
+  |  Only the caller's initial string pointer is modified.
+  */
+gchar *
+gkrellm_dup_token(gchar **string, gchar *delimeters)
+	{
+	gchar			*str, *s, *delims;
+	gboolean		quoted = FALSE;
+
+	if (!string || !*string)
+		return g_strdup("");
+
+	str = *string;
+	delims = delimeters ? delimeters : " \t\n";
+	while (any(*str, delims))
+		++str;
+
+	if (*str == '"')
+		{
+		quoted = TRUE;
+		++str;
+		for (s = str; *s && *s != '"'; ++s)
+			;
+		}
+	else
+		for (s = str; *s && !any(*s, delims); ++s)
+			;
+
+	*string = (quoted && *s) ? s + 1 : s;
+	return g_strndup(str, s - str);
+	}
 
   /* Cut out an optionally quoted string.  This is destructive to the src.
   */
