@@ -41,9 +41,8 @@ AscentValues    large_font_ascents,
                 normal_font_ascents,
                 small_font_ascents;
 
-static int
-setup_ascents(GdkFont *font, AscentValues *av)
-    {
+static int setup_ascents(GdkFont *font, AscentValues *av)
+{
     GLYPHMETRICS gm;
     MAT2 mat2;
     HWND wnd;
@@ -77,18 +76,21 @@ setup_ascents(GdkFont *font, AscentValues *av)
 
     err = GetGlyphOutline(hdc, 'A', GGO_METRICS, &gm, 0, NULL, &mat2);
     if (err == GDI_ERROR) {
+        ReleaseDC(wnd, hdc);
         return 1;
     }
     av->upper_ascent = gm.gmBlackBoxY;
 
     err = GetGlyphOutline(hdc,'8', GGO_METRICS,  &gm, 0, NULL, &mat2);
     if (err == GDI_ERROR) {
+        ReleaseDC(wnd, hdc);
         return 1;
     }
     av->digit_ascent = gm.gmBlackBoxY;
 
     err = GetGlyphOutline(hdc, 'a', GGO_METRICS,  &gm, 0, NULL, &mat2);
     if (err == GDI_ERROR) {
+        ReleaseDC(wnd, hdc);
         return 1;
     }
     av->lower_ascent[0] = gm.gmBlackBoxY;
@@ -96,12 +98,14 @@ setup_ascents(GdkFont *font, AscentValues *av)
 
     err = GetGlyphOutline(hdc, 'f', GGO_METRICS,  &gm, 0, NULL, &mat2);
     if (err == GDI_ERROR) {
+        ReleaseDC(wnd, hdc);
         return 1;
     }
     av->lower_ascent[1] = gm.gmBlackBoxY;
 
     err = GetGlyphOutline(hdc, 'i', GGO_METRICS,  &gm, 0, NULL, &mat2);
     if (err == GDI_ERROR) {
+        ReleaseDC(wnd, hdc);
         return 1;
     }
     av->lower_ascent[2] = gm.gmBlackBoxY;
@@ -109,16 +113,17 @@ setup_ascents(GdkFont *font, AscentValues *av)
 
     err = GetGlyphOutline(hdc, 'y', GGO_METRICS,  &gm, 0, NULL, &mat2);
     if (err == GDI_ERROR) {
+        ReleaseDC(wnd, hdc);
         return 1;
     }
     av->descent = gm.gmBlackBoxY - av->lower_ascent[0];
 
+    ReleaseDC(wnd, hdc);
     return 0;
-    }
+}
 
-static void
-fix_ascents(gchar *s, gint len, AscentValues *av, gint *ascent, gint *descent)
-    {
+static void fix_ascents(gchar *s, gint len, AscentValues *av, gint *ascent, gint *descent)
+{
     gint    i, map, a = 0, a_max = 0, d = 0;
     gchar   c;
 
@@ -141,26 +146,26 @@ fix_ascents(gchar *s, gint len, AscentValues *av, gint *ascent, gint *descent)
         }
     *ascent = a_max;
     *descent = d;
-    }
+}
 
-void
-gkrellm_winop_text_extents(GdkFont *font, gchar *text, gint text_length,
+void gkrellm_winop_text_extents(GdkFont *font, gchar *text, gint text_length,
         gint *lbearing, gint *rbearing,
         gint *width, gint *ascent, gint *descent)
-    {
+{
     static gint font_load_count;
     int done = 1;
 
     gdk_text_extents(font, text, text_length, lbearing, rbearing,
             width, ascent, descent);
     if (_GK.font_load_count != font_load_count)
-        {  /* _GK.font_load_count increments when I load the theme fonts */
+    {  /* _GK.font_load_count increments when I load the theme fonts */
         setup_ascents(_GK.large_font, &large_font_ascents);
         setup_ascents(_GK.normal_font, &normal_font_ascents);
         done = setup_ascents(_GK.small_font, &small_font_ascents);
         font_load_count = _GK.font_load_count;
-        }
-    if (done == 0) {
+    }
+    if (done == 0) 
+    {
         // only do this if setup_ascents passed
         if (font == _GK.large_font)
             fix_ascents(text, text_length, &large_font_ascents, ascent, descent);
@@ -173,20 +178,18 @@ gkrellm_winop_text_extents(GdkFont *font, gchar *text, gint text_length,
         *ascent -= 3;
         *descent -= 1;
     }
-    }
+}
 
 void
 gkrellm_winop_reset(void)
-	{
-	}
+{
+}
 
 //void
 //gkrellm_winop_withdraw(void)
 //	{
 //	}
 
-
-
 UINT WM_GKRELLMCALLBACK;
 extern void create_config_window(void);
 LONG oldval;
@@ -227,8 +230,7 @@ LRESULT CALLBACK newWndProc(HWND hWnd, UINT Msg, WPARAM wParam, LPARAM lParam)
 
 void
 gkrellm_winop_options(gint argc, gchar **argv)
-  {
-
+{
     NOTIFYICONDATA nid;
 
     // get gtk window procedure and set new one
@@ -306,3 +308,23 @@ void
 gkrellm_winop_apply_rootpixmap_transparency(void)
 	{
 	}
+
+void
+gkrellm_winop_state_skip_taskbar(gboolean state)
+	{
+	}
+
+void
+gkrellm_winop_state_skip_pager(gboolean state)
+	{
+	}
+
+void
+gkrellm_winop_state_above(gboolean state)
+	{
+	}
+
+void
+gkrellm_winop_state_below(gboolean state)
+	{
+	}
