@@ -27,6 +27,9 @@
 #include <sys/file.h>
 #endif
 
+#include <pwd.h>
+#include <sys/types.h>
+
 #include <gdk/gdkx.h>
 #include <X11/Xmd.h>
 #include <X11/SM/SMlib.h>
@@ -93,14 +96,16 @@ cb_ice_connection_messages(IceConn ice_connection, gint source,
 static void
 smc_connect(gint argc, gchar **argv)
 	{
-	SmProp			userid, program, restart, clone, *props[4];
-	SmPropValue		userid_val;
+	SmProp			userid, program, restart, clone, pid, *props[5];
+	SmPropValue		userid_val, pid_val;
 	SmcCallbacks	*callbacks;
 	SmcConn			smc_connection;
 	IceConn			ice_connection;
-	gchar			error_string[256], user_id_string[16];
+	struct passwd	*pwd;
+	uid_t			uid;
+	gchar			error_string[256], pid_str[16], userid_string[256];
 	gulong			mask;
-	gint			i;
+	gint			i, j;
 
 	/* Session manager callbacks
 	*/
@@ -117,7 +122,7 @@ smc_connect(gint argc, gchar **argv)
 						NULL /* share ICE connection */,
 						SmProtoMajor, SmProtoMinor, mask,
 						callbacks,
-						NULL, &client_id,
+						_GK.session_id, &client_id,
 						sizeof(error_string), error_string);
 	g_free(callbacks);
 	if (!smc_connection)
@@ -131,24 +136,43 @@ smc_connect(gint argc, gchar **argv)
 	userid.type = SmARRAY8;
 	userid.num_vals = 1;
 	userid.vals = &userid_val;
-	snprintf(user_id_string, sizeof(user_id_string), "%d", geteuid());
-	userid_val.value = user_id_string;
-	userid_val.length = strlen(user_id_string);
+	uid = getuid();
+	if ((pwd = getpwuid(uid)) != NULL)
+		snprintf(userid_string, sizeof(userid_string), "%s", pwd->pw_name);
+	else
+		snprintf(userid_string, sizeof(userid_string), "%d", uid);
+	userid_val.value = userid_string;
+	userid_val.length = strlen(userid_string);
+
+	pid.name = SmProcessID;
+	pid.type = SmARRAY8;
+	pid.num_vals = 1;
+	pid.vals = &pid_val;
+	sprintf(pid_str, "%i", getpid());
+	pid_val.value = (SmPointer) pid_str;
+	pid_val.length = strlen(pid_str);
 
 	restart.name = SmRestartCommand;
 	restart.type = SmLISTofARRAY8;
-	restart.vals = g_new0(SmPropValue, argc);
-	for (i = 0; i < argc; ++i)
-		{
-		restart.vals[i].value = (SmPointer) argv[i];
-		restart.vals[i].length = strlen(argv[i]);
-		}
-	restart.num_vals = argc;
+	restart.vals = g_new0(SmPropValue, argc + 2);
+	j = 0;
+	for (i = 0; i < argc; ++i) {
+		if ( strcmp(argv[i], "--sm-client-id") ) {
+			restart.vals[j].value = (SmPointer) argv[i];
+			restart.vals[j++].length = strlen(argv[i]);
+		} else
+			i++;
+	}
+	restart.vals[j].value = (SmPointer) "--sm-client-id";
+	restart.vals[j++].length = strlen("--sm-client-id");
+	restart.vals[j].value = (SmPointer) client_id;
+	restart.vals[j++].length = strlen(client_id);
+	restart.num_vals = j;
 
 	clone.name = SmCloneCommand;
 	clone.type = SmLISTofARRAY8;
 	clone.vals = restart.vals;
-	clone.num_vals = restart.num_vals;
+	clone.num_vals = restart.num_vals - 2;
 
 	program.name = SmProgram;
 	program.type = SmARRAY8;
@@ -159,8 +183,9 @@ smc_connect(gint argc, gchar **argv)
 	props[1] = &userid;
 	props[2] = &restart;
 	props[3] = &clone;
+	props[4] = &pid;
 
-	SmcSetProperties(smc_connection, 4, props);
+	SmcSetProperties(smc_connection, 5, props);
 	g_free(restart.vals);
 
 	ice_connection = SmcGetIceConnection(smc_connection);
